@@ -14,7 +14,8 @@
 
 ;(setq load-path (append (list (expand-file-name "~/site-lisp")) load-path))
 
-(autoload 'LilyPond-mode "lilypond-mode" "LilyPond Editing Mode" t)
-(add-to-list 'auto-mode-alist '("\\.ly$" . LilyPond-mode))
-(add-hook 'LilyPond-mode-hook (lambda () (turn-on-font-lock)))
+(autoload 'lilypond-mode "lilypond-mode" "LilyPond Editing Mode" t)
+(add-to-list 'auto-mode-alist '("\\.ly\\'" . lilypond-mode))
+(add-to-list 'auto-mode-alist '("\\.ily\\'" . lilypond-mode))
+(add-hook 'lilypond-mode-hook (lambda () (turn-on-font-lock)))
 
