@@ -108,8 +108,10 @@ void
 Accidental_engraver::update_local_key_signature (SCM new_sig)
 {
   last_keysig_ = new_sig;
-  set_context_property_on_children (
-    context (), ly_symbol2scm ("localAlterations"), new_sig);
+  preorder_walk (context (), [&] (Context *ctx) {
+    set_property (ctx, ly_symbol2scm ("localAlterations"),
+                  ly_deep_copy (new_sig));
+  });
 
   Context *trans = context ()->get_parent ();
 
