@@ -94,14 +94,14 @@ Stencil
 Bracket::make_axis_constrained_bracket (Grob *me, Real length, Axis a,
                                         Direction dir, Interval gap)
 {
-  Drul_array<Real> edge_height
-    = from_scm (get_property (me, "edge-height"), Drul_array<Real> (1.0, 1.0));
-  Drul_array<Real> flare = from_scm (get_property (me, "bracket-flare"),
-                                     Drul_array<Real> (0.0, 0.0));
-  Drul_array<Real> shorten
-    = from_scm (get_property (me, "shorten-pair"), Drul_array<Real> (0.0, 0.0));
-  Drul_array<Real> overshoot = from_scm (get_property (me, "break-overshoot"),
-                                         Drul_array<Real> (0.0, 0.0));
+  auto edge_height
+    = from_scm (get_property (me, "edge-height"), Drul_array (1.0, 1.0));
+  auto flare
+    = from_scm (get_property (me, "bracket-flare"), Drul_array (0.0, 0.0));
+  auto shorten
+    = from_scm (get_property (me, "shorten-pair"), Drul_array (0.0, 0.0));
+  auto overshoot
+    = from_scm (get_property (me, "break-overshoot"), Drul_array (0.0, 0.0));
 
   // Make sure that it points in the correct direction:
   scale_drul (&edge_height, -dir);
