@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2010--2022 Jan Nieuwenhuizen <janneke@gnu.org>
+  Copyright (C) 2010--2023 Jan Nieuwenhuizen <janneke@gnu.org>
   Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@
 #include "context.hh"
 #include "context-mod.hh"
 
-LY_DEFINE (ly_get_context_mods, "ly:get-context-mods",
-           1, 0, 0, (SCM contextmod),
+LY_DEFINE (ly_get_context_mods, "ly:get-context-mods", 1, 0, 0,
+           (SCM contextmod),
            R"(
 Returns the list of context modifications stored in @var{contextmod}.
            )")
@@ -31,8 +31,8 @@ Returns the list of context modifications stored in @var{contextmod}.
   return tr->get_mods ();
 }
 
-LY_DEFINE (ly_add_context_mod, "ly:add-context-mod",
-           2, 0, 0, (SCM contextmods, SCM modification),
+LY_DEFINE (ly_add_context_mod, "ly:add-context-mod", 2, 0, 0,
+           (SCM contextmods, SCM modification),
            R"(
 Adds the given context @var{modification} to the list @var{contextmods} of
 context modifications.
@@ -43,8 +43,7 @@ context modifications.
   return SCM_UNSPECIFIED;
 }
 
-LY_DEFINE (ly_make_context_mod, "ly:make-context-mod",
-           0, 1, 0, (SCM mod_list),
+LY_DEFINE (ly_make_context_mod, "ly:make-context-mod", 0, 1, 0, (SCM mod_list),
            R"(
 Create a context modification, optionally initialized via the list of
 modifications @var{mod-list}.
@@ -59,8 +58,8 @@ modifications @var{mod-list}.
     return Context_mod ().smobbed_copy ();
 }
 
-LY_DEFINE (ly_context_mod_apply_x, "ly:context-mod-apply!",
-           2, 0, 0, (SCM context, SCM mod),
+LY_DEFINE (ly_context_mod_apply_x, "ly:context-mod-apply!", 2, 0, 0,
+           (SCM context, SCM mod),
            R"(
 Apply the context modification @var{mod} to @var{context}.
            )")
