@@ -25,6 +25,7 @@
 #include "international.hh"
 #include "listener.hh"
 #include "ly-scm-list.hh"
+#include "ly-smob-list.hh"
 #include "main.hh"
 #include "output-def.hh"
 #include "profile.hh"
@@ -930,6 +931,17 @@ measure_position (Context const *context)
   return measure_position (context, measure_length (context));
 }
 
+Moment
+scaled_measure_position (Context const *context,
+                         Rational const &scaled_measure_length)
+{
+  const auto factor
+    = from_scm (get_property (context, "meterScalingFactor"), Rational (1));
+  const auto actual_len = scaled_measure_length * factor;
+  const auto actual_pos = measure_position (context, actual_len);
+  return actual_pos / factor;
+}
+
 // Find the moment where a note of duration dur happening now will end.
 Moment
 note_end_mom (Context const *context, Duration const *dur)
@@ -958,14 +970,25 @@ measure_number (Context const *context)
   return bn;
 }
 
-void
-set_context_property_on_children (Context *trans, SCM sym, SCM val)
+static void
+unchecked_preorder_walk (Context *context,
+                         const std::function<void (Context *)> &visit)
 {
-  set_property (trans, sym, ly_deep_copy (val));
-  for (SCM p = trans->children_contexts (); scm_is_pair (p); p = scm_cdr (p))
+  visit (context);
+  SCM children = context->children_contexts ();
+  for (auto *child : as_ly_smob_list<Context> (children))
     {
-      Context *trg = unsmob<Context> (scm_car (p));
-      set_context_property_on_children (trg, sym, ly_deep_copy (val));
+      assert (child); // Context guarantees that the list has only Contexts
+      unchecked_preorder_walk (child, visit);
+    }
+}
+
+void
+preorder_walk (Context *context, const std::function<void (Context *)> &visit)
+{
+  if (context && visit)
+    {
+      unchecked_preorder_walk (context, visit);
     }
 }
 
