@@ -33,10 +33,10 @@
 
 #include "translator.icc"
 
-struct Figure_group
+struct Figure_group final
 {
-  Spanner *group_;
-  Spanner *continuation_line_;
+  Spanner *group_ = nullptr;
+  Spanner *continuation_line_ = nullptr;
 
   SCM number_;
   SCM alteration_;
@@ -45,17 +45,10 @@ struct Figure_group
   SCM augmented_slash_;
   SCM text_;
 
-  Item *figure_item_;
-  Stream_event *current_event_;
+  Item *figure_item_ = nullptr;
+  Stream_event *current_event_ = nullptr;
 
-  Figure_group ()
-  {
-    figure_item_ = 0;
-    continuation_line_ = 0;
-    reset_figure ();
-    group_ = 0;
-    current_event_ = 0;
-  }
+  Figure_group () { reset_figure (); }
   /* Reset (or init) all figure information to FALSE */
   void reset_figure ()
   {
@@ -102,7 +95,7 @@ struct Figure_group
   }
 };
 
-struct Figured_bass_engraver : public Engraver
+struct Figured_bass_engraver final : public Engraver
 {
   TRANSLATOR_DECLARATIONS (Figured_bass_engraver);
   void clear_spanners ();
@@ -114,10 +107,10 @@ struct Figured_bass_engraver : public Engraver
 
 protected:
   std::vector<Figure_group> groups_;
-  Spanner *alignment_;
+  Spanner *alignment_ = nullptr;
   std::vector<Stream_event *> new_events_;
-  bool continuation_;
-  bool new_event_found_;
+  bool continuation_ = false;
+  bool new_event_found_ = false;
 
   Moment stop_moment_;
   Boolean_event_listener rest_listener_;
@@ -134,9 +127,6 @@ protected:
 Figured_bass_engraver::Figured_bass_engraver (Context *c)
   : Engraver (c)
 {
-  alignment_ = 0;
-  continuation_ = false;
-  new_event_found_ = false;
 }
 
 void
@@ -158,7 +148,7 @@ Figured_bass_engraver::start_translation_timestep ()
   rest_listener_.reset ();
   new_events_.clear ();
   for (vsize i = 0; i < groups_.size (); i++)
-    groups_[i].current_event_ = 0;
+    groups_[i].current_event_ = nullptr;
 
   continuation_ = false;
 }
@@ -252,7 +242,7 @@ Figured_bass_engraver::clear_spanners ()
     return;
 
   announce_end_grob (alignment_, SCM_EOL);
-  alignment_ = 0;
+  alignment_ = nullptr;
 
   if (from_scm<bool> (get_property (this, "figuredBassCenterContinuations")))
     center_repeated_continuations ();
@@ -262,13 +252,13 @@ Figured_bass_engraver::clear_spanners ()
       if (groups_[i].group_)
         {
           announce_end_grob (groups_[i].group_, SCM_EOL);
-          groups_[i].group_ = 0;
+          groups_[i].group_ = nullptr;
         }
 
       if (groups_[i].continuation_line_)
         {
           announce_end_grob (groups_[i].continuation_line_, SCM_EOL);
-          groups_[i].continuation_line_ = 0;
+          groups_[i].continuation_line_ = nullptr;
         }
     }
 
@@ -330,7 +320,7 @@ Figured_bass_engraver::process_music ()
 
       groups_[k].reset_figure ();
       groups_[k].current_event_ = new_events_[i];
-      groups_[k].figure_item_ = 0;
+      groups_[k].figure_item_ = nullptr;
       k++;
     }
 
@@ -367,7 +357,7 @@ Figured_bass_engraver::process_music ()
                   Pointer_group_interface::add_grob (
                     line, ly_symbol2scm ("figures"), item);
 
-                  group.figure_item_ = 0;
+                  group.figure_item_ = nullptr;
                 }
             }
           else if (group.continuation_line_)
@@ -400,7 +390,7 @@ Figured_bass_engraver::process_music ()
             }
         }
       for (vsize i = 0; i < junk_continuations.size (); i++)
-        groups_[junk_continuations[i]].continuation_line_ = 0;
+        groups_[junk_continuations[i]].continuation_line_ = nullptr;
     }
 
   create_grobs ();
@@ -451,7 +441,7 @@ Figured_bass_engraver::create_grobs ()
               && scm_is_null (group.augmented_slash_))
             {
               // Convert `<_>` to an invisible digit.
-              number = scm_from_int (0);
+              number = to_scm (0);
               set_property (item, "transparent", SCM_BOOL_T);
               set_property (item, "implicit", SCM_BOOL_T);
             }
@@ -486,12 +476,12 @@ Figured_bass_engraver::create_grobs ()
               set_property (event, "diminished", SCM_BOOL_F);
               set_property (event, "augmented-slash", SCM_BOOL_F);
 
-              text = ly_call (proc, scm_from_int (0), event->self_scm (),
+              text = ly_call (proc, to_scm (0), event->self_scm (),
                               context ()->self_scm ());
             }
           else
             {
-              text = ly_string2scm ("0");
+              text = to_scm ("0");
             }
 
           set_property (group.figure_item_, "transparent", SCM_BOOL_T);
