@@ -39,7 +39,7 @@ operator<(Grob_pq_entry const &a, Grob_pq_entry const &b)
   return a.end_ < b.end_;
 }
 
-class Grob_pq_engraver : public Engraver
+class Grob_pq_engraver final : public Engraver
 {
 public:
   TRANSLATOR_DECLARATIONS (Grob_pq_engraver);
@@ -102,7 +102,7 @@ Grob_pq_engraver::process_acknowledged ()
   SCM *tail = &lst;
   for (vsize i = 0; i < started_now_.size (); i++)
     {
-      *tail = scm_acons (started_now_[i].end_.smobbed_copy (),
+      *tail = scm_acons (to_scm (started_now_[i].end_),
                          started_now_[i].grob_->self_scm (), SCM_EOL);
       tail = SCM_CDRLOC (*tail);
     }
