@@ -161,11 +161,11 @@ Hairpin::print (SCM smob)
   if (circled_tip)
     thick = from_scm<double> (get_property (me, "thickness"), 1.0)
             * Staff_symbol_referencer::line_thickness (me);
-  Drul_array<Real> shorten
-    = from_scm (get_property (me, "shorten-pair"), Drul_array<Real> (0.0, 0.0));
+  auto shorten
+    = from_scm (get_property (me, "shorten-pair"), Drul_array (0.0, 0.0));
 
   auto endpoint_alignments = from_scm (get_property (me, "endpoint-alignments"),
-                                       Drul_array<Real> (-1, 1));
+                                       Drul_array (-1.0, 1.0));
 
   for (const auto d : {LEFT, RIGHT})
     {
