@@ -17,14 +17,16 @@
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "font-interface.hh"
+#include "interval-set.hh"
+#include "lookup.hh"
 #include "note-head.hh"
+#include "paper-column.hh"
+#include "pitch.hh"
+#include "pointer-group-interface.hh"
+#include "spanner.hh"
 #include "staff-symbol-referencer.hh"
 #include "staff-symbol.hh"
-#include "lookup.hh"
-#include "spanner.hh"
-#include "pointer-group-interface.hh"
-#include "paper-column.hh"
-#include "interval-set.hh"
 
 #include <map>
 
@@ -143,12 +145,14 @@ struct Head_data
   Interval head_extent_;
   Interval ledger_extent_;
   Interval accidental_extent_;
+  Interval ledger_shortening_range_;
   Head_data ()
   {
     position_ = 0;
     head_extent_.set_empty ();
     ledger_extent_.set_empty ();
     accidental_extent_.set_empty ();
+    ledger_shortening_range_.set_empty ();
   }
 };
 
@@ -169,7 +173,7 @@ struct Ledger_request
   }
 };
 
-typedef std::map<int, Drul_array<Ledger_request>> Ledger_requests;
+typedef std::map<vsize, Drul_array<Ledger_request>> Ledger_requests;
 
 /*
   TODO: ledger share a lot of info. Lots of room to optimize away
@@ -225,7 +229,7 @@ Ledger_line_spanner::print (SCM smob)
           ledger_extent.widen (length_fraction * head_extent.length ());
 
           Direction vdir = Direction (sign (pos != 0 ? pos : 1));
-          int rank = h->get_column ()->get_rank ();
+          vsize rank = h->get_column ()->get_rank ();
 
           reqs[rank][vdir].max_ledger_extent_.unite (ledger_extent);
           reqs[rank][vdir].max_head_extent_.unite (head_extent);
@@ -238,7 +242,32 @@ Ledger_line_spanner::print (SCM smob)
           hd.ledger_extent_ = ledger_extent;
           hd.head_extent_ = head_extent;
           if (Grob *g = unsmob<Grob> (get_object (h, "accidental-grob")))
-            hd.accidental_extent_ = g->extent (common_x, X_AXIS);
+            {
+              hd.accidental_extent_ = g->extent (common_x, X_AXIS);
+
+              std::string glyph;
+              if (from_scm<bool> (get_property (g, "parenthesized")))
+                {
+                  glyph = "accidentals.rightparen";
+                }
+              else
+                {
+                  SCM glyph_scm = get_property (g, "glyph-name");
+                  if (scm_is_string (glyph_scm))
+                    {
+                      glyph = from_scm<std::string> (glyph_scm);
+                    }
+                }
+
+              if (!glyph.empty ())
+                {
+                  Font_metric *fm = Font_interface::get_default_font (g);
+                  hd.ledger_shortening_range_
+                    = fm->ledger_shortening_range (glyph) * (1 / halfspace);
+                  // Compensate for rounding errors.
+                  hd.ledger_shortening_range_.widen (1e-3);
+                }
+            }
           reqs[rank][vdir].heads_.push_back (hd);
         }
     }
@@ -308,6 +337,11 @@ Ledger_line_spanner::print (SCM smob)
               Interval &ledger_size = lr.heads_[h].ledger_extent_;
               Interval &head_size = lr.heads_[h].head_extent_;
               Interval &acc_extent = lr.heads_[h].accidental_extent_;
+              int pos = lr.heads_[h].position_;
+
+              // TODO: shall this be made user-configurable?
+              const Interval ledger_shortening_range
+                = lr.heads_[h].ledger_shortening_range_;
 
               // Limit ledger extents to a maximum to preserve space
               // between ledgers when note heads get close.
@@ -321,8 +355,8 @@ Ledger_line_spanner::print (SCM smob)
                   Interval x_extent = ledger_size;
 
                   // Notes with accidental signs get shorter ledgers.
-                  // (Only happens for the furthest note in the column.)
-                  if (l == 0 && !acc_extent.is_empty ())
+                  if (ledger_shortening_range.contains (lpos - pos)
+                      && !acc_extent.is_empty ())
                     {
                       const auto dist
                         = (acc_extent.right () + head_size.left ()) / 2;
@@ -330,10 +364,6 @@ Ledger_line_spanner::print (SCM smob)
                       Real left_shorten
                         = std::max (-ledger_size[LEFT] + dist, 0.0);
                       x_extent[LEFT] += left_shorten;
-                      /*
-                        TODO: shorten 2 ledger lines for the case
-                        natural + downstem.
-                      */
                     }
                   if (x_extent.is_empty ())
                     continue;
@@ -389,7 +419,7 @@ ADD_INTERFACE (Ledger_line_spanner,
 This spanner draws the ledger lines of a staff.  This is a separate grob
 because it has to process all potential collisions between all note heads.  The
 thickness of ledger lines is controlled by the @code{ledger-line-thickness}
-property of the @ref{StaffSymbol} grob.
+property of the @iref{StaffSymbol} grob.
                )",
 
                /* properties */
@@ -407,7 +437,7 @@ struct Ledgered_interface
 ADD_INTERFACE (Ledgered_interface,
                R"(
 Objects that need ledger lines, typically note heads.  See also
-@ref{ledger-line-spanner-interface}.
+@iref{ledger-line-spanner-interface}.
                )",
 
                /* properties */
