@@ -50,6 +50,7 @@
 #include "relocate.hh"
 #include "std-vector.hh"
 #include "string-convert.hh"
+#include "time-tracer.hh"
 #include "version.hh"
 #include "warn.hh"
 
@@ -62,6 +63,9 @@
 #include <clocale>
 #include <cstdio>
 #include <cstring>
+#include <string_view>
+
+using namespace std::literals;
 
 // Global options that can be overridden through command line.
 // Most variables are defined in file `global-vars.cc'.
@@ -137,7 +141,7 @@ static Long_option_init options_static[] = {
 #endif
   {_i ("LOGLEVEL"), "loglevel", 'l',
    _i ("print log messages according to LOGLEVEL,\n"
-       "which is either NONE, ERROR, WARNING,\n"
+       "which is either NONE, ERROR, WARN,\n"
        "BASIC, PROGRESS, INFO (default), or DEBUG")},
   {_i ("FILE"), "output", 'o',
    _i ("write output to FILE (suffix will be added)\n"
@@ -444,6 +448,7 @@ main_with_guile (void *, int, char **)
     do_chroot_jail ();
 #endif
 
+  tracer_global.log_end_event (); // Boot Guile
   Lily::lilypond_main (files);
 
   /* Unreachable.  */
@@ -626,7 +631,7 @@ parse_argv (int argc, char **argv)
           break;
         default:
           programming_error (
-            to_string ("unhandled short option: %c", opt->shortname_char_));
+            to_string_f ("unhandled short option: %c", opt->shortname_char_));
           assert (false);
           break;
         }
@@ -693,6 +698,8 @@ setup_guile_env ()
 int
 main (int argc, char **argv)
 {
+  tracer_global.log_first_begin_event ("lilypond"sv);
+
   /*
     Handle old-style environment equivalent to
     old-style -V or --verbose command arguments.
@@ -709,6 +716,42 @@ main (int argc, char **argv)
     identify (stderr);
 
   setup_paths (argv[0]);
+
+  // Change to the directory specified by the --output option.
+  if (!output_name_global.empty ())
+    {
+      // If the --output option names an existing directory, use it as such;
+      // otherwise, treat it as a path and split it.
+      std::string dir;
+      std::string file;
+      if (is_dir (output_name_global))
+        {
+          dir = output_name_global;
+        }
+      else
+        {
+          File_name fn (output_name_global);
+          dir = fn.dir_part ();
+          file = fn.file_part ();
+        }
+
+      if (!dir.empty () && (dir != "."))
+        {
+          if (const auto &wdir = get_working_directory (); dir != wdir)
+            {
+              global_path.prepend (wdir);
+              message (_f ("Changing working directory to: `%s'", dir));
+              if (chdir (dir.c_str ()) != 0)
+                {
+                  error (_f ("unable to change directory to: `%s'", dir));
+                }
+            }
+        }
+
+      // Having handled the directory part, remove it from the option value.
+      output_name_global = file;
+    }
+
   setup_guile_env (); // set up environment variables to pass into Guile API
 
 #if !GS_API
@@ -717,6 +760,7 @@ main (int argc, char **argv)
 #endif
 
   // Start up Guile API using main_with_guile as a callback.
+  tracer_global.log_begin_event ("Boot Guile"sv);
   scm_boot_guile (argc, argv, main_with_guile, 0);
 
   /* Only reachable if Guile exits.  That is an error.  */
