@@ -34,22 +34,14 @@
 #include <algorithm>
 #include <vector>
 
-struct Finger_tuple
+struct Finger_tuple final
 {
-  Grob *head_;
-  Grob *script_;
-  Stream_event *note_event_;
-  Stream_event *finger_event_;
-  bool follow_into_staff_;
-  int position_;
-
-  Finger_tuple ()
-  {
-    position_ = 0;
-    head_ = script_ = 0;
-    note_event_ = finger_event_ = 0;
-    follow_into_staff_ = false;
-  }
+  Grob *head_ = nullptr;
+  Grob *script_ = nullptr;
+  Stream_event *note_event_ = nullptr;
+  Stream_event *finger_event_ = nullptr;
+  bool follow_into_staff_ = false;
+  int position_ = 0;
 };
 
 bool
@@ -58,7 +50,7 @@ operator<(Finger_tuple const &a, Finger_tuple const &b)
   return a.position_ < b.position_;
 }
 
-class New_fingering_engraver : public Engraver
+class New_fingering_engraver final : public Engraver
 {
   std::vector<Finger_tuple> fingerings_;
   std::vector<Finger_tuple> stroke_fingerings_;
@@ -67,8 +59,8 @@ class New_fingering_engraver : public Engraver
 
   std::vector<Grob *> heads_;
   std::vector<Grob *> accidentals_;
-  Grob *stem_;
-  Item *note_column_;
+  Grob *stem_ = nullptr;
+  Item *note_column_ = nullptr;
 
   void position_all ();
 
@@ -350,8 +342,8 @@ void
 New_fingering_engraver::stop_translation_timestep ()
 {
   position_all ();
-  stem_ = 0;
-  note_column_ = 0;
+  stem_ = nullptr;
+  note_column_ = nullptr;
   heads_.clear ();
   accidentals_.clear ();
 }
@@ -404,7 +396,6 @@ New_fingering_engraver::position_all ()
 New_fingering_engraver::New_fingering_engraver (Context *c)
   : Engraver (c)
 {
-  stem_ = 0;
 }
 
 void
