@@ -150,8 +150,7 @@ Real
 Page_turn_engraver::penalty (Rational rest_len)
 {
   const auto min_turn
-    = from_scm (get_property (this, "minimumPageTurnLength"), Moment (1))
-        .main_part_;
+    = from_scm (get_property (this, "pageTurnMinimumRestLength"), Rational (1));
 
   return (rest_len < min_turn) ? infinity_f : 0;
 }
@@ -174,7 +173,7 @@ Page_turn_engraver::acknowledge_bar_line (Grob_info_t<Item> gi)
 {
   if (!found_special_bar_line_)
     {
-      auto glyph = robust_scm2string (get_property (gi.grob (), "glyph"), "");
+      auto glyph = from_scm (get_property (gi.grob (), "glyph"), "");
       found_special_bar_line_ = is_bar_line_special (glyph);
     }
 }
@@ -201,7 +200,7 @@ Page_turn_engraver::acknowledge_note_head (Grob_info gi)
 
   if (rest_begin_ <= repeat_begin_)
     repeat_begin_rest_length_ = (now_mom () - repeat_begin_).main_part_;
-  note_end_ = now_mom () + dur_ptr->get_length ();
+  note_end_ = now_mom () + Rational (*dur_ptr);
 }
 
 void
@@ -256,7 +255,7 @@ Page_turn_engraver::stop_translation_timestep ()
         {
           if (auto *bar = unsmob<Item> (get_property (this, "currentBarLine")))
             {
-              auto glyph = robust_scm2string (get_property (bar, "glyph"), "");
+              auto glyph = from_scm (get_property (bar, "glyph"), "");
               found_special_bar_line_ = is_bar_line_special (glyph);
             }
         }
@@ -304,10 +303,9 @@ Page_turn_engraver::stop_translation_timestep ()
       Real pen = penalty ((now_mom () - rest_begin_).main_part_
                           + repeat_begin_rest_length_);
 
-      const auto minimumRepeatLengthForPageTurn
-        = from_scm (get_property (this, "minimumRepeatLengthForPageTurn"),
-                    -Moment::infinity ());
-      if (minimumRepeatLengthForPageTurn > (now_mom () - repeat_begin_))
+      const auto pageTurnMinimumRepeatLength = from_scm (
+        get_property (this, "pageTurnMinimumRepeatLength"), Rational (0));
+      if (pageTurnMinimumRepeatLength > (now_mom () - repeat_begin_).main_part_)
         pen = infinity_f;
 
       if (pen == infinity_f)
@@ -442,8 +440,8 @@ Decide where page turns are allowed to go.
                 /* read */
                 R"(
 currentBarLine
-minimumPageTurnLength
-minimumRepeatLengthForPageTurn
+pageTurnMinimumRestLength
+pageTurnMinimumRepeatLength
                 )",
 
                 /* write */
