@@ -126,8 +126,8 @@ void
 Pango_font::register_font_file (const std::string &filename,
                                 const std::string &ps_name, int face_index)
 {
-  scm_hash_set_x (physical_font_tab_, ly_string2scm (ps_name),
-                  ly_list (ly_string2scm (filename), to_scm (face_index)));
+  scm_hash_set_x (physical_font_tab_, to_scm (ps_name),
+                  ly_list (to_scm (filename), to_scm (face_index)));
 }
 
 size_t
@@ -243,13 +243,13 @@ Pango_font::get_glyph_desc (PangoGlyphInfo const &pgi,
     {
       PangoGlyph char_cpp = pg & ~PANGO_GLYPH_UNKNOWN_FLAG;
       SCM char_scm = scm_integer_to_char (to_scm<uint64_t> (char_cpp));
-      // Use scm_to_locale_string here, not ly_scm2string (which would encode in
+      // Use scm_to_locale_string here, not from_scm<std::string> (which would encode in
       // UTF-8) because we're going to output to a console.
       unique_stdlib_ptr<char> str (
         scm_to_locale_string (scm_string (ly_list (char_scm))));
       SCM name = Unicode::char_2_formal_name (char_scm);
-      std::string formal_name
-        = scm_is_string (name) ? " " + ly_scm2string (name) : "";
+      const auto formal_name
+        = scm_is_string (name) ? " " + from_scm<std::string> (name) : "";
       warning (_f ("no glyph for character '%s' (U+%04X%s) in font `%s'",
                    str.get (), char_cpp, formal_name.c_str (),
                    file_name.c_str ()));
@@ -262,8 +262,11 @@ Pango_font::get_glyph_desc (PangoGlyphInfo const &pgi,
       FT_Error errorcode
         = FT_Get_Glyph_Name (ftface, pg, glyph_name, GLYPH_NAME_LEN);
       if (errorcode)
-        programming_error (_f ("FT_Get_Glyph_Name () error: %s",
-                               freetype_error_string (errorcode).c_str ()));
+        {
+          programming_error (
+            to_string_f ("FT_Get_Glyph_Name () error: %s",
+                         freetype_error_string (errorcode).c_str ()));
+        }
       else
         {
           // There are fonts like `Symbola.ttf` version 10.23 that have a
@@ -292,9 +295,9 @@ Pango_font::get_glyph_desc (PangoGlyphInfo const &pgi,
   if (glyph_name[0] == '\0' && has_glyph_names)
     {
       programming_error (
-        _f ("Glyph has no name, but font supports glyph naming.\n"
-            "Skipping glyph U+%04X, file %s",
-            pg, file_name.c_str ()));
+        to_string_f ("Glyph has no name, but font supports glyph naming.\n"
+                     "Skipping glyph U+%04X, file %s",
+                     pg, file_name.c_str ()));
       return SCM_BOOL_F;
     }
 
@@ -317,10 +320,11 @@ Pango_font::get_glyph_desc (PangoGlyphInfo const &pgi,
       FT_Error errorcode = FT_Get_CID_From_Glyph_Index (ftface, pg, &cid_id);
       if (errorcode)
         {
-          programming_error (_f ("FT_Get_CID_From_Glyph_Index () error: %s\n"
-                                 "Skipping glyph U+%04X, file %s",
-                                 freetype_error_string (errorcode).c_str (), pg,
-                                 file_name.c_str ()));
+          programming_error (
+            to_string_f ("FT_Get_CID_From_Glyph_Index () error: %s\n"
+                         "Skipping glyph U+%04X, file %s",
+                         freetype_error_string (errorcode).c_str (), pg,
+                         file_name.c_str ()));
           return SCM_BOOL_F;
         }
       char_id = scm_from_uint32 (cid_id);
@@ -491,11 +495,10 @@ Pango_font::pango_item_string_stencil (PangoGlyphItem const *glyph_item,
         = text.substr (glyph_item->item->offset, glyph_item->item->length);
       // See function `glyph-string` in file `output-ps.scm` for documentation
       // of the arguments.
-      SCM expr
-        = ly_list (ly_symbol2scm ("glyph-string"), self_scm (),
-                   ly_string2scm (ps_name), to_scm (size), to_scm (cid_keyed),
-                   glyph_exprs, ly_string2scm (file_name), to_scm (face_index),
-                   ly_string2scm (substr), clusters);
+      SCM expr = ly_list (ly_symbol2scm ("glyph-string"), self_scm (),
+                          to_scm (ps_name), to_scm (size), to_scm (cid_keyed),
+                          glyph_exprs, to_scm (file_name), to_scm (face_index),
+                          to_scm (substr), clusters);
 
       return Stencil (string_extent, expr);
     }
@@ -572,9 +575,9 @@ Pango_font::text_stencil (Output_def * /* state */, const std::string &str,
     {
       // Encapsulate to allow a short-cut for backends that also use
       // Pango for rendering.
-      SCM exp = ly_list (ly_symbol2scm ("utf-8-string"),
-                         ly_string2scm (description_string ()),
-                         ly_string2scm (str), dest.expr ());
+      SCM exp
+        = ly_list (ly_symbol2scm ("utf-8-string"),
+                   to_scm (description_string ()), to_scm (str), dest.expr ());
       dest = Stencil (dest.extent_box (), exp);
     }
   return dest;
