@@ -29,7 +29,7 @@
 
 #include "translator.icc"
 
-class Parenthesis_engraver : public Engraver
+class Parenthesis_engraver final : public Engraver
 {
   TRANSLATOR_DECLARATIONS (Parenthesis_engraver);
 
@@ -64,7 +64,10 @@ Parenthesis_engraver::acknowledge_grob (Grob_info info)
       // is important for accidental placement, but won't
       // work with parenthesis friends.  TODO: find a nice
       // way to merge the two.
-      && !has_interface<Accidental_interface> (g))
+      && !has_interface<Accidental_interface> (g)
+      // Similar for TabNoteHead
+      && !(
+        g->internal_has_interface (ly_symbol2scm ("tab-note-head-interface"))))
     {
       SCM id = get_property (g, "parenthesis-id");
       bool must_add_to_alist = false;
