@@ -30,7 +30,7 @@
 
 #include "translator.icc"
 
-class Part_combine_engraver : public Engraver
+class Part_combine_engraver final : public Engraver
 {
   TRANSLATOR_DECLARATIONS (Part_combine_engraver);
 
@@ -44,11 +44,11 @@ protected:
   void create_item (Stream_event *ev);
 
 private:
-  Item *text_;
-  Stream_event *new_event_; // Event happened at this moment
+  Item *text_ = nullptr;
+  Stream_event *new_event_ = nullptr; // Event happened at this moment
   Boolean_event_listener note_listener_;
   // Event possibly from an earlier moment waiting to create a text:
-  Stream_event *waiting_event_;
+  Stream_event *waiting_event_ = nullptr;
 };
 
 void
@@ -63,21 +63,18 @@ Part_combine_engraver::listen_part_combine (Stream_event *ev)
 Part_combine_engraver::Part_combine_engraver (Context *c)
   : Engraver (c)
 {
-  text_ = 0;
-  new_event_ = 0;
-  waiting_event_ = 0;
 }
 
 void
 Part_combine_engraver::create_item (Stream_event *ev)
 {
-  SCM what = scm_car (get_property (ev, "class"));
+  SCM what = get_property (ev, "part-combine-status");
   SCM text = SCM_EOL;
-  if (scm_is_eq (what, ly_symbol2scm ("solo-one-event")))
+  if (scm_is_eq (what, ly_symbol2scm ("solo1")))
     text = get_property (this, "soloText");
-  else if (scm_is_eq (what, ly_symbol2scm ("solo-two-event")))
+  else if (scm_is_eq (what, ly_symbol2scm ("solo2")))
     text = get_property (this, "soloIIText");
-  else if (scm_is_eq (what, ly_symbol2scm ("unisono-event")))
+  else if (scm_is_eq (what, ly_symbol2scm ("unisono")))
     text = get_property (this, "aDueText");
 
   if (Text_interface::is_markup (text))
@@ -97,7 +94,7 @@ Part_combine_engraver::process_music ()
           || !from_scm<bool> (get_property (this, "partCombineTextsOnNote")))
         {
           create_item (waiting_event_);
-          waiting_event_ = 0;
+          waiting_event_ = nullptr;
         }
     }
 }
@@ -124,8 +121,8 @@ Part_combine_engraver::acknowledge_stem (Grob_info i)
 void
 Part_combine_engraver::stop_translation_timestep ()
 {
-  text_ = 0;
-  new_event_ = 0;
+  text_ = nullptr;
+  new_event_ = nullptr;
   note_listener_.reset ();
 }
 
