@@ -387,8 +387,9 @@ Slur::calc_control_points (SCM smob)
   if (debug_slurs)
     {
       std::string total = best->card ();
-      total += to_string (" TOTAL=%.2f idx=%zu", best->score (), best->index_);
-      set_property (me, "annotation", ly_string2scm (total));
+      total
+        += to_string_f (" TOTAL=%.2f idx=%zu", best->score (), best->index_);
+      set_property (me, "annotation", to_scm (total));
     }
 
   SCM controls = SCM_EOL;
@@ -516,7 +517,7 @@ Slur_score_state::get_y_attachment_range () const
 bool
 spanner_less (Spanner *s1, Spanner *s2)
 {
-  Slice b1, b2;
+  Interval_t<vsize> b1, b2;
   for (const auto d : {LEFT, RIGHT})
     {
       b1[d] = s1->get_bound (d)->get_column ()->get_rank ();
@@ -727,12 +728,12 @@ Slur_score_state::enumerate_attachments (Drul_array<Real> end_ys) const
     = staff_space_
       * from_scm<double> (get_property (slur_, "minimum-length"), 2.0);
 
-  for (int i = 0; dir_ * os[LEFT][Y_AXIS] <= dir_ * end_ys[LEFT]; i++)
+  while (dir_ * os[LEFT][Y_AXIS] <= dir_ * end_ys[LEFT])
     {
       os[RIGHT] = base_attachments_[RIGHT];
-      for (int j = 0; dir_ * os[RIGHT][Y_AXIS] <= dir_ * end_ys[RIGHT]; j++)
-        {
 
+      while (dir_ * os[RIGHT][Y_AXIS] <= dir_ * end_ys[RIGHT])
+        {
           Drul_array<bool> attach_to_stem;
           for (const auto d : {LEFT, RIGHT})
             {
