@@ -23,17 +23,6 @@
 #include "file-name.hh"
 #include "file-path.hh"
 
-Sources::Sources ()
-{
-  path_ = 0;
-}
-
-void
-Sources::set_path (File_path *f)
-{
-  path_ = f;
-}
-
 /**
    Open a file. If the name is not absolute, look in CURRENT_DIR first.
    Afterwards, check the rest of the path_.
@@ -72,17 +61,13 @@ Sources::find_full_path (std::string file_string,
     file_string = current_dir + '/' + file_string;
 
   // Otherwise, check the rest of the path.
-  else if (path_)
-    {
-      return path_->find (file_string);
-    }
-  return file_string;
+  return path_.find (file_string);
 }
 
 std::string
 Sources::search_path () const
 {
-  return path_->to_string ();
+  return path_.to_string ();
 }
 
 void
@@ -121,7 +106,7 @@ optionally be specified.
        = lex->file_name_strings_.begin ();
        i != lex->file_name_strings_.end (); ++i)
     {
-      lst = scm_cons (ly_string2scm (*i), lst);
+      lst = scm_cons (to_scm (*i), lst);
     }
   return scm_reverse_x (lst, SCM_EOL);
 }
@@ -141,6 +126,6 @@ In general, this function can embed arbitrary files into LilyPond's PDF output
   if (SCM_UNBNDP (parser))
     parser = scm_fluid_ref (Lily::f_parser);
   auto *const p = LY_ASSERT_SMOB (Lily_parser, parser, 2);
-  p->lexer_->file_name_strings_.push_back (ly_scm2string (filename));
+  p->lexer_->file_name_strings_.push_back (from_scm<std::string> (filename));
   return SCM_UNSPECIFIED;
 }
