@@ -35,7 +35,7 @@
 /* Perform a staff. Individual notes should have their instrument
   (staff-wide) set, so we override play_element ()
 */
-class Staff_performer : public Performer
+class Staff_performer final : public Performer
 {
 public:
   TRANSLATOR_DECLARATIONS (Staff_performer);
@@ -72,11 +72,11 @@ private:
   };
 
   std::string instrument_string_;
-  int channel_;
-  Audio_instrument *instrument_;
-  Audio_text *instrument_name_;
-  Audio_text *name_;
-  Audio_tempo *tempo_;
+  int channel_ = -1;
+  Audio_instrument *instrument_ = nullptr;
+  Audio_text *instrument_name_ = nullptr;
+  Audio_text *name_ = nullptr;
+  Audio_tempo *tempo_ = nullptr;
   std::unordered_map<std::string, Audio_staff *> staff_map_;
   std::unordered_map<std::string, int> channel_map_;
   // Would prefer to have the following two items be
@@ -121,12 +121,7 @@ midiSkipOffset
                 )");
 
 Staff_performer::Staff_performer (Context *c)
-  : Performer (c),
-    channel_ (-1),
-    instrument_ (0),
-    instrument_name_ (0),
-    name_ (0),
-    tempo_ (0)
+  : Performer (c)
 {
 }
 
@@ -214,10 +209,10 @@ Staff_performer::set_instrument_name (const std::string &voice)
 void
 Staff_performer::stop_translation_timestep ()
 {
-  name_ = 0;
-  tempo_ = 0;
-  instrument_name_ = 0;
-  instrument_ = 0;
+  name_ = nullptr;
+  tempo_ = nullptr;
+  instrument_name_ = nullptr;
+  instrument_ = nullptr;
 }
 
 void
@@ -247,10 +242,11 @@ Staff_performer::new_instrument_string ()
   // mustn't ask Score for instrument: it will return piano!
   SCM minstr = get_property (this, "midiInstrument");
 
-  if (!scm_is_string (minstr) || ly_scm2string (minstr) == instrument_string_)
+  if (!scm_is_string (minstr)
+      || from_scm<std::string> (minstr) == instrument_string_)
     return "";
 
-  instrument_string_ = ly_scm2string (minstr);
+  instrument_string_ = from_scm<std::string> (minstr);
 
   return instrument_string_;
 }
