@@ -185,6 +185,21 @@ Stem::support_head (Grob *me)
   if (heads.size () == 1)
     return heads[0];
 
+  // In a whole-note chord, harmonic heads are centered on the normal heads.
+  // They don't accurately represent the extent of the chord, so we ignore them.
+  if (is_invisible (me))
+    {
+      auto ext_heads = extremal_heads_if (me, [] (auto *h) {
+        return !scm_is_eq (get_property (h, "style"),
+                           ly_symbol2scm ("harmonic"));
+      });
+      const auto d = get_grob_direction (me);
+      if (d && ext_heads[-d])
+        {
+          return ext_heads[-d];
+        }
+    }
+
   return first_head (me);
 }
 
@@ -215,13 +230,10 @@ Stem::last_head (Grob *me)
   return 0;
 }
 
-/*
-  START is part where stem reaches `last' head.
-
-  This function returns a drul with (bottom-head, top-head).
-*/
+// Return a drul with (bottom-head, top-head), accepting only the heads that
+// satisfy the predicate.  The pointers are null if no head satisfies it.
 Drul_array<Grob *>
-Stem::extremal_heads (Grob *me)
+Stem::extremal_heads_if (Grob *me, bool (*predicate) (Grob *))
 {
   // N.B. `me` could be a NoteColumn rather than a Stem.  This isn't very clean,
   // but this was implemented here first, and rearranging it without rearranging
@@ -235,9 +247,13 @@ Stem::extremal_heads (Grob *me)
   Drul_array<Grob *> exthead;
   extract_grob_set (me, "note-heads", heads);
 
-  for (vsize i = 0; i < heads.size (); i++)
+  for (auto *n : heads)
     {
-      Grob *n = heads[i];
+      if (!predicate (n))
+        {
+          continue;
+        }
+
       int p = Staff_symbol_referencer::get_rounded_position (n);
 
       if (p < extpos[DOWN]) /* < lowest note unison: take FIRST one */
@@ -255,6 +271,15 @@ Stem::extremal_heads (Grob *me)
   return exthead;
 }
 
+/*
+  This function returns a drul with (bottom-head, top-head).
+*/
+Drul_array<Grob *>
+Stem::extremal_heads (Grob *me)
+{
+  return extremal_heads_if (me, [] (auto) { return true; });
+}
+
 /* The staff positions, in ascending order.
  * If FILTER, include the main column of noteheads only */
 std::vector<int>
@@ -263,12 +288,37 @@ Stem::note_head_positions (Grob *me, bool filter)
   std::vector<int> ps;
   extract_grob_set (me, "note-heads", heads);
   Grob *xref = common_refpoint_of_array (heads, me, X_AXIS);
+  const bool filter_stemless = filter && is_invisible (me);
 
   for (vsize i = heads.size (); i--;)
     {
       Grob *n = heads[i];
-      if (filter && n->relative_coordinate (xref, X_AXIS) != 0.0)
-        continue;
+      if (filter)
+        {
+          // The main column can include smaller notes that are shifted to align
+          // with normal notes.  For example, using Emmentaler, a quarter-note
+          // head sharing an up-stem with a half-note head is offset by about
+          // 0.0732, and a harmonic head centered on a normal whole note is
+          // offset by about 0.331.  This allowance might need to be tuned as
+          // other cases are tested.
+          //
+          // It is illogical to limit this check to whole-note harmonics, but it
+          // is being done to avoid changing the decisions of
+          // Note_collision_interface in other cases.  Some of those decisions
+          // do require improvement, but without a lot of diligence, the risk of
+          // regressions is high.
+          const bool filter_centered
+            = filter_stemless
+              && scm_is_eq (get_property (n, "style"),
+                            ly_symbol2scm ("harmonic"));
+          const auto tolerated
+            = filter_centered ? Interval (0.0, 0.375) : Interval (0.0);
+          const auto x = n->relative_coordinate (xref, X_AXIS);
+          if (!tolerated.contains (x))
+            {
+              continue;
+            }
+        }
 
       int p = Staff_symbol_referencer::get_rounded_position (n);
       ps.push_back (p);
@@ -557,27 +607,34 @@ Stem::calc_positioning_done (SCM smob)
 
   Real thick = thickness (me);
 
-  Grob *hed = support_head (me);
+  // Align other heads relative to the "support head."
+  {
+    const bool i_am_invisible = is_invisible (me);
+    auto *const sup = support_head (me);
+    const auto sup_extent = sup->extent (sup, X_AXIS);
+    for (auto *const h : heads)
+      {
+        if (h == sup)
+          {
+            // Skipping the calculations below is a performance optimization.
+            // Even if they were performed, they shouldn't move the support head
+            // relative to itself.
+            continue;
+          }
+        // In a whole-note chord, center harmonic heads on the normal heads.
+        // Otherwise, justify all heads to the invisible stem.
+        const bool align_on_center = i_am_invisible
+                                     && scm_is_eq (get_property (h, "style"),
+                                                   ly_symbol2scm ("harmonic"));
+        const auto h_extent = h->extent (h, X_AXIS);
+        const auto amount = align_on_center
+                              ? (sup_extent.center () - h_extent.center ())
+                              : (sup_extent[dir] - h_extent[dir]);
+        if (!std::isnan (amount)) // empty heads can produce NaN
+          h->translate_axis (amount, X_AXIS);
+      }
+  }
 
-  bool is_harmonic_centered = false;
-  for (vsize i = 0; i < heads.size (); i++)
-    is_harmonic_centered = is_harmonic_centered
-                           || scm_is_eq (get_property (heads[i], "style"),
-                                         ly_symbol2scm ("harmonic"));
-  is_harmonic_centered = is_harmonic_centered && is_invisible (me);
-
-  Real w = hed->extent (hed, X_AXIS)[dir];
-  for (vsize i = 0; i < heads.size (); i++)
-    {
-      Real amount = w - heads[i]->extent (heads[i], X_AXIS)[dir];
-
-      if (is_harmonic_centered)
-        amount = hed->extent (hed, X_AXIS).center ()
-                 - heads[i]->extent (heads[i], X_AXIS).center ();
-
-      if (!std::isnan (amount)) // empty heads can produce NaN
-        heads[i]->translate_axis (amount, X_AXIS);
-    }
   bool parity = true;
   Real lastpos = Staff_symbol_referencer::get_position (heads[0]);
   int threshold = from_scm (get_property (me, "note-collision-threshold"), 1);
@@ -992,10 +1049,12 @@ Stem::offset_callback (SCM smob)
       Real r = std::isnan (real_attach) ? 0.0 : real_attach;
 
       /* If not centered: correct for stem thickness.  */
+      const Real epsilon = 1e-3; // compensate rounding in font
       std::string style
         = robust_symbol2string (get_property (f, "style"), "default");
-      if (attach != 0.0 && style != "neomensural" && style != "petrucci"
-          && style != "blackpetrucci" && style != "semipetrucci")
+      if (std::abs (attach) > epsilon && style != "neomensural"
+          && style != "petrucci" && style != "blackpetrucci"
+          && style != "semipetrucci")
         {
           Direction d = get_grob_direction (me);
           Real rule_thick = thickness (me);
