@@ -173,7 +173,9 @@ add_partial_ellipse_segments (Lazy_skyline_pair *skyline,
     {
       Real ang = linear_interpolate (
         static_cast<Real> (i), 0, static_cast<Real> (quantization), start, end);
-      Offset pt (offset_directed (ang).scale (rad));
+      Offset pt (offset_directed (ang));
+      pt[X_AXIS] *= rad[X_AXIS];
+      pt[Y_AXIS] *= rad[Y_AXIS];
       if (i > 0)
         skyline->add_segment (transform, last, pt, th);
       else
@@ -211,7 +213,7 @@ add_round_filled_box_segments (Lazy_skyline_pair *skyline,
   Real x_scale = sqrt (sqr (transform.get_xx ()) + sqr (transform.get_yx ()));
   Real y_scale = sqrt (sqr (transform.get_xy ()) + sqr (transform.get_yy ()));
   bool rounded = (diameter * std::max (x_scale, y_scale) > 0.5);
-  bool rotated = (transform.get_yx () || transform.get_xy ());
+  bool rotated = (transform.get_yx () != 0.0 || transform.get_xy () != 0.0);
 
   std::vector<Box> boxes;
   if (!rotated && !rounded)
@@ -243,9 +245,8 @@ add_round_filled_box_segments (Lazy_skyline_pair *skyline,
         }
 
       /* draw rounded corners */
-      if (radius)
+      if (radius != 0.0)
         {
-          Offset rad (radius, radius);
           Drul_array<Real> cx;
           Drul_array<Real> cy;
 
@@ -263,7 +264,8 @@ add_round_filled_box_segments (Lazy_skyline_pair *skyline,
                     Real ang = linear_interpolate (
                       static_cast<Real> (i), 0,
                       static_cast<Real> (quantization), 0., 90.);
-                    Offset pt (offset_directed (ang).scale (rad));
+                    Offset pt (offset_directed (ang));
+                    pt *= radius;
                     Offset inter (cx[h] + h * pt[X_AXIS],
                                   cy[v] + v * pt[Y_AXIS]);
 
@@ -536,7 +538,7 @@ add_named_glyph_segments (Lazy_skyline_pair *skyline,
   Font_metric *fm = unsmob<Font_metric> (fm_scm);
   expr = scm_cdr (expr);
   SCM glyph = scm_car (expr);
-  std::string glyph_s = ly_scm2string (glyph);
+  const auto glyph_s = from_scm<std::string> (glyph);
 
   Open_type_font *open_fm = dynamic_cast<Open_type_font *> (
     dynamic_cast<Modified_font_metric *> (fm)->original_font ());
@@ -764,8 +766,9 @@ interpret_stencil_for_skyline (Lazy_skyline_pair *skyline,
 
 SCM
 Grob::maybe_pure_internal_simple_skylines_from_extents (Grob *me, Axis a,
-                                                        bool pure, int beg,
-                                                        int end, bool ignore_x,
+                                                        bool pure, vsize beg,
+                                                        vsize end,
+                                                        bool ignore_x,
                                                         bool ignore_y)
 {
   std::vector<Box> boxes;
@@ -794,8 +797,8 @@ Grob::pure_simple_vertical_skylines_from_extents (SCM smob, SCM begscm,
                                                   SCM endscm)
 {
   auto *const me = LY_ASSERT_SMOB (Grob, smob, 1);
-  int beg = from_scm (begscm, 0);
-  int end = from_scm (endscm, INT_MAX);
+  auto beg = from_scm (begscm, vsize {0});
+  auto end = from_scm (endscm, vsize {INT_MAX});
   // We cannot measure the widths before line breaking,
   // so we assume that the width is infinite: pass ignore_x=true
   return maybe_pure_internal_simple_skylines_from_extents (
@@ -820,8 +823,8 @@ Grob::pure_simple_horizontal_skylines_from_extents (SCM smob, SCM begscm,
                                                     SCM endscm)
 {
   auto *const me = LY_ASSERT_SMOB (Grob, smob, 1);
-  int beg = from_scm (begscm, 0);
-  int end = from_scm (endscm, INT_MAX);
+  auto beg = from_scm (begscm, vsize {0});
+  auto end = from_scm (endscm, vsize {INT_MAX});
   // If the grob is cross staff, we cannot measure its Y-extent before
   // wayyyy downstream (after spacing of axis groups is done).
   // Thus, we assume that the Y extent is infinite for cross staff grobs.
@@ -901,7 +904,7 @@ Grob::horizontal_skylines_from_stencil (SCM smob)
 
 SCM
 Grob::internal_skylines_from_element_stencils (Grob *me, Axis a, bool pure,
-                                               int beg, int end)
+                                               vsize beg, vsize end)
 {
   extract_grob_set (me, "elements", elts);
   std::vector<Real> x_pos;
@@ -968,8 +971,8 @@ Grob::pure_vertical_skylines_from_element_stencils (SCM smob, SCM beg_scm,
                                                     SCM end_scm)
 {
   auto *const me = LY_ASSERT_SMOB (Grob, smob, 1);
-  int beg = from_scm (beg_scm, 0);
-  int end = from_scm (end_scm, 0);
+  auto beg = from_scm (beg_scm, vsize {0});
+  auto end = from_scm (end_scm, vsize {0});
   return internal_skylines_from_element_stencils (me, X_AXIS, true, beg, end);
 }
 
@@ -981,7 +984,7 @@ Grob::pure_horizontal_skylines_from_element_stencils (SCM smob, SCM beg_scm,
                                                       SCM end_scm)
 {
   auto *const me = LY_ASSERT_SMOB (Grob, smob, 1);
-  int beg = from_scm (beg_scm, 0);
-  int end = from_scm (end_scm, 0);
+  auto beg = from_scm (beg_scm, vsize {0});
+  auto end = from_scm (end_scm, vsize {0});
   return internal_skylines_from_element_stencils (me, Y_AXIS, true, beg, end);
 }
