@@ -29,6 +29,7 @@
 #include "international.hh"
 #include "lily-imports.hh"
 #include "lookup.hh"
+#include "main.hh"
 #include "output-def.hh"
 #include "page-layout-problem.hh"
 #include "paper-column.hh"
@@ -40,13 +41,17 @@
 #include "staff-symbol-referencer.hh"
 #include "system-start-delimiter.hh"
 #include "text-interface.hh"
+#include "time-tracer.hh"
 #include "unpure-pure-container.hh"
 #include "warn.hh"
 
 #include <algorithm>
 #include <limits>
+#include <string_view>
 #include <vector>
 
+using namespace std::literals;
+
 Grob_array *
 System::all_elements ()
 {
@@ -233,7 +238,7 @@ System::get_footnote_grobs_in_range (vsize start, vsize end)
   for (vsize i = 0; i < footnote_grobs.size (); i++)
     {
       Grob *at_bat = footnote_grobs[i];
-      int pos = at_bat->spanned_column_rank_interval ()[LEFT];
+      vsize pos = at_bat->spanned_column_rank_interval ()[LEFT];
       bool end_of_line_visible = true;
       if (Spanner *s = dynamic_cast<Spanner *> (at_bat))
         {
@@ -262,22 +267,21 @@ System::get_footnote_grobs_in_range (vsize start, vsize end)
           if (!item->break_visible ())
             continue;
           // safeguard to bring down the column rank so that end of line footnotes show up on the correct line
-          if (pos == int (start) && item->break_status_dir () != RIGHT)
+          if (pos == start && item->break_status_dir () != RIGHT)
             continue;
-          if (pos == int (end) && item->break_status_dir () != LEFT)
+          if (pos == end && item->break_status_dir () != LEFT)
             continue;
-          if (pos != int (end) && pos != int (start)
-              && item->break_status_dir () != CENTER)
+          if (pos != end && pos != start && item->break_status_dir () != CENTER)
             continue;
         }
 
-      if (pos < int (start))
+      if (pos < start)
         continue;
-      if (pos > int (end))
+      if (pos > end)
         continue;
-      if (pos == int (start) && end_of_line_visible)
+      if (pos == start && end_of_line_visible)
         continue;
-      if (pos == int (end) && !end_of_line_visible)
+      if (pos == end && !end_of_line_visible)
         continue;
       if (!at_bat->is_live ())
         continue;
@@ -346,7 +350,7 @@ System::num_footnotes ()
 bool
 grob_2D_less (Grob *g1, Grob *g2)
 {
-  int sri[] = {0, 0};
+  vsize sri[] = {0, 0};
   Grob *gs[] = {g1, g2};
 
   for (int i = 0; i < 2; i++)
@@ -397,7 +401,7 @@ System::footnotes_after_line_breaking (SCM smob)
 {
   auto *const sys = LY_ASSERT_SMOB (System, smob, 1);
 
-  Interval_t<int> sri = sys->spanned_column_rank_interval ();
+  Interval_t<vsize> sri = sys->spanned_column_rank_interval ();
   std::vector<Grob *> footnote_grobs
     = sys->get_footnote_grobs_in_range (sri[LEFT], sri[RIGHT]);
   std::sort (footnote_grobs.begin (), footnote_grobs.end (), grob_2D_less);
@@ -454,8 +458,8 @@ System::break_into_pieces (std::vector<Column_x_positions> const &breaking)
       std::vector<Paper_column *> const &c (breaking[i].cols_);
       pscore_->typeset_system (system);
 
-      int st = c[0]->get_rank ();
-      int end = c.back ()->get_rank ();
+      vsize st = c[0]->get_rank ();
+      vsize end = c.back ()->get_rank ();
       Interval iv (pure_y_extent (this, st, end));
       set_property (system, "pure-Y-extent", to_scm (iv));
 
@@ -504,7 +508,7 @@ System::add_column (Paper_column *p)
       ga = unsmob<Grob_array> (scm_ga);
     }
 
-  p->set_rank (static_cast<int> (ga->size ()));
+  p->set_rank (static_cast<vsize> (ga->size ()));
 
   ga->add (p);
   Axis_group_interface::add_element (this, p);
@@ -513,15 +517,19 @@ System::add_column (Paper_column *p)
 void
 System::pre_processing ()
 {
+  Grob_array *all = all_elements ();
+
   /*
     Each breakable Item calls back to this System to append two clones of
     itself (for before and after a break) to the vector.  We stop after
     breaking the originals and don't invite the clones to break themselves.
   */
-  Grob_array *all = all_elements ();
-  vsize num_original_grobs = all->size ();
-  for (vsize i = 0; i < num_original_grobs; i++)
-    all->grob (i)->break_breakable_item (this);
+  {
+    auto trace_slice = tracer_global.log_scope ("Break items"sv);
+    vsize num_original_grobs = all->size ();
+    for (vsize i = 0; i < num_original_grobs; i++)
+      all->grob (i)->break_breakable_item (this);
+  }
 
   debug_output (_f ("Grob count %zu", all->size ()));
 
@@ -530,23 +538,35 @@ System::pre_processing ()
     array, and should be processed before the original is potentially
     killed.
   */
-  for (vsize i = all->size (); i--;)
-    all->grob (i)->handle_prebroken_dependencies ();
+  {
+    auto trace_slice = tracer_global.log_scope ("Handle dependencies"sv);
+    for (vsize i = all->size (); i--;)
+      all->grob (i)->handle_prebroken_dependencies ();
+  }
 
-  for (Grob *g : all->array_reference ())
-    g->fixup_refpoint ();
+  {
+    auto trace_slice = tracer_global.log_scope ("Fix up refpoints"sv);
+    for (Grob *g : all->array_reference ())
+      g->fixup_refpoint ();
+  }
 
-  get_property (this, "before-line-breaking");
-  for (Grob *g : all->array_reference ())
-    {
-      (void) get_property (g, "before-line-breaking");
-    }
+  {
+    auto trace_slice = tracer_global.log_scope ("before-line-breaking"sv);
+    get_property (this, "before-line-breaking");
+    for (Grob *g : all->array_reference ())
+      {
+        (void) get_property (g, "before-line-breaking");
+      }
+  }
 
-  get_property (this, "springs-and-rods");
-  for (Grob *g : all->array_reference ())
-    {
-      (void) get_property (g, "springs-and-rods");
-    }
+  {
+    auto trace_slice = tracer_global.log_scope ("springs-and-rods"sv);
+    get_property (this, "springs-and-rods");
+    for (Grob *g : all->array_reference ())
+      {
+        (void) get_property (g, "springs-and-rods");
+      }
+  }
 }
 
 void
@@ -788,7 +808,7 @@ System::get_vertical_alignment (SCM smob)
 // Finds the neighboring staff in the given direction over bounds
 Grob *
 System::get_neighboring_staff (Direction dir, Grob *vertical_axis_group,
-                               Interval_t<int> bounds)
+                               Interval_t<vsize> bounds)
 {
   Grob *align = unsmob<Grob> (get_object (this, "vertical-alignment"));
   if (!align)
@@ -935,8 +955,8 @@ SCM
 System::calc_pure_height (SCM smob, SCM start_scm, SCM end_scm)
 {
   System *me = unsmob<System> (smob);
-  int start = from_scm<int> (start_scm);
-  int end = from_scm<int> (end_scm);
+  auto start = from_scm<vsize> (start_scm);
+  auto end = from_scm<vsize> (end_scm);
 
   Interval begin = me->begin_of_line_pure_height (start, end);
   Interval rest = me->rest_of_line_pure_height (start, end);
