@@ -41,7 +41,7 @@ protected:
 
 public:
   TRANSLATOR_DECLARATIONS (Time_signature_performer);
-  void listen_time_signature (Stream_event *);
+  void listen_reference_time_signature (Stream_event *);
 };
 
 void
@@ -56,7 +56,7 @@ Time_signature_performer::Time_signature_performer (Context *c)
 }
 
 void
-Time_signature_performer::listen_time_signature (Stream_event *ev)
+Time_signature_performer::listen_reference_time_signature (Stream_event *ev)
 {
   event_ = ev;
 }
@@ -139,7 +139,7 @@ Time_signature_performer::process_music ()
         from_scm<Rational> (scm_car (fr)), // numerator
         from_scm<Rational> (scm_cdr (fr)), // denominator
         static_cast<int> (beat_base_clocks.numerator ()));
-      Audio_element_info info (audio_, 0);
+      Audio_element_info info (audio_, event_);
       announce_element (info);
     }
 }
@@ -156,7 +156,7 @@ Time_signature_performer::stop_translation_timestep ()
 void
 Time_signature_performer::boot ()
 {
-  ADD_LISTENER (time_signature);
+  ADD_LISTENER (reference_time_signature);
 }
 
 ADD_TRANSLATOR (Time_signature_performer,
