@@ -133,11 +133,12 @@ Tuplet_bracket::bracket_basic_visibility (Spanner *me)
   */
   if (!from_scm<bool> (bracket_vis_prop))
     {
-      auto *const start_col = me->get_bound (LEFT)->get_column ();
-      auto *const end_col = me->get_bound (RIGHT)->get_column ();
+      const auto bounds = me->get_bounds ();
+      auto *const start_col = bounds[LEFT]->get_column ();
+      auto *const end_col = bounds[RIGHT]->get_column ();
       auto start_mom = from_scm (get_property (start_col, "when"), Moment (0));
       auto end_mom = from_scm (get_property (end_col, "when"), Moment (0));
-      if (start_mom == end_mom && !me->get_bound (LEFT)->break_status_dir ())
+      if (start_mom == end_mom && !bounds[LEFT]->break_status_dir ())
         bracket_visibility = false;
     }
 
@@ -337,7 +338,7 @@ Tuplet_bracket::print (SCM smob)
 
   if (bracket_visibility)
     {
-      Drul_array<Real> zero (0, 0);
+      const Drul_array zero (0.0, 0.0);
 
       Drul_array<Real> shorten
         = from_scm (get_property (me, "shorten-pair"), zero);
@@ -416,8 +417,8 @@ Tuplet_bracket::print (SCM smob)
   return mol.smobbed_copy ();
 }
 
-void
-Tuplet_bracket::get_bounds (Grob *me, Grob **left, Grob **right)
+Drul_array<Grob *>
+Tuplet_bracket::get_bounds (Grob *me)
 {
   extract_grob_set (me, "note-columns", columns);
   vsize l = 0;
@@ -428,13 +429,10 @@ Tuplet_bracket::get_bounds (Grob *me, Grob **left, Grob **right)
   while (r > l && Note_column::has_rests (columns[r - 1]))
     r--;
 
-  *left = *right = 0;
-
   if (l < r)
-    {
-      *left = columns[l];
-      *right = columns[r - 1];
-    }
+    return {columns[l], columns[r - 1]};
+  else
+    return {};
 }
 
 /*
@@ -521,9 +519,9 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
       /*
         Use outer non-rest columns to determine slope
       */
-      Grob *left_col = 0;
-      Grob *right_col = 0;
-      get_bounds (me, &left_col, &right_col);
+      const auto bounds = get_bounds (me);
+      auto *const left_col = bounds[LEFT];
+      auto *const right_col = bounds[RIGHT];
       if (left_col && right_col)
         {
           Interval rv = Note_column::cross_staff_extent (right_col, commony);
@@ -562,7 +560,7 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
 
       Real last_x = x;
 
-      if (*dy)
+      if (*dy != 0.0)
         {
           Real slope = fabs (*dy / (x1 - x0));
           Real max_slope = 0;
@@ -577,7 +575,7 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
           if (par_beam)
             beam_positions
               = from_scm (get_property (par_beam, "quantized-positions"),
-                          Drul_array<Real> (0.0, 0.0));
+                          Drul_array (0.0, 0.0));
           else
             {
               for (vsize i = columns.size (); i--;)
@@ -589,7 +587,7 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
                         {
                           beam_positions = from_scm (
                             get_property (beam, "quantized-positions"),
-                            Drul_array<Real> (0.0, 0.0));
+                            Drul_array (0.0, 0.0));
                           sub_x0 = robust_relative_extent (beam, commonx,
                                                            X_AXIS)[LEFT];
                           sub_x1 = robust_relative_extent (beam, commonx,
@@ -602,14 +600,14 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
 
           beam_dy = beam_positions[RIGHT] - beam_positions[LEFT];
 
-          if (beam_dy)
+          if (beam_dy != 0.0)
             {
-              if (!sub_x1)
+              if (sub_x1 == 0.0)
                 beam_slope = fabs (beam_dy / (x1 - x0));
               else
                 beam_slope = fabs (beam_dy / (sub_x1 - sub_x0));
 
-              if (beam_slope)
+              if (beam_slope != 0.0)
                 max_slope = std::max (beam_slope, max_slope_factor);
               else
                 max_slope = max_slope_factor;
@@ -650,8 +648,8 @@ Tuplet_bracket::calc_position_and_height (Spanner *me, Real *offset, Real *dy)
       if (!tuplets[i]->is_live ())
         continue;
 
-      Drul_array<Real> positions = from_scm (
-        get_property (tuplets[i], "positions"), Drul_array<Real> (0.0, 0.0));
+      const auto positions = from_scm (get_property (tuplets[i], "positions"),
+                                       Drul_array (0.0, 0.0));
 
       Real other_dy = positions[RIGHT] - positions[LEFT];
 
