@@ -127,6 +127,14 @@ Volta_engraver::listen_fine (Stream_event *)
   should_close_end_ = true;
 }
 
+static bool
+are_volta_numbers_equal (Stream_event *a, Stream_event *b)
+{
+  SCM volta_numbers_sym = ly_symbol2scm ("volta-numbers");
+  return ly_is_equal (get_property (a, volta_numbers_sym),
+                      get_property (b, volta_numbers_sym));
+}
+
 void
 Volta_engraver::listen_volta_span (Stream_event *ev)
 {
@@ -136,40 +144,71 @@ Volta_engraver::listen_volta_span (Stream_event *ev)
   auto &layer = layers_[layer_no];
 
   // It is common to have the same repeat structure in multiple voices, so we
-  // ignore simultaneous events; but it might not be a bad thing to add some
-  // consistency checks here if they could catch some kinds of user error.
+  // ignore simultaneous events; but it is nice to perform some consistency
+  // checks to catch likely errors and improve the user's debugging experience.
 
   auto dir = from_scm<Direction> (get_property (ev, "span-direction"));
   if (dir == START)
     {
       if (!layer.start_ev_)
-        layer.start_ev_ = ev;
+        {
+          layer.start_ev_ = ev;
+        }
+      else if (!are_volta_numbers_equal (layer.start_ev_, ev))
+        {
+          // Include the volta numbers in the message because they might not be
+          // obvious if the source has the legacy \alternative syntax with
+          // implied \volta.
+          const auto nums = ly_scm_write_string (
+            get_property (ev, ly_symbol2scm ("volta-numbers")));
+          ev->warning (_f ("discarding conflicting volta numbers: %s", nums));
+        }
     }
   else if (dir == STOP)
     {
-      if (!layer.start_ev_)
+      // This handles the possibility of an empty alternative: a simultaneous
+      // start and stop with the same volta spec.  This will not handle
+      // consecutive empty alternatives well, since it tracks only one start
+      // event, but it covers the most important case: an empty final
+      // alternative.
+      if (layer.start_ev_ && are_volta_numbers_equal (layer.start_ev_, ev))
         {
-          if (!layer.stop_prev_ev_)
-            layer.stop_prev_ev_ = ev;
+          if (!layer.stop_curr_ev_)
+            layer.stop_curr_ev_ = ev;
         }
-      else
+      else if (!layer.stop_prev_ev_)
         {
-          // When an alternative is empty, we can in one timestep receive a stop
-          // event for the previous alternative and the current alternative.
-          // (This code will not handle consecutive empty alternatives, but it
-          // covers the most important case: an empty final alternative.)
-          SCM volta_numbers_sym = ly_symbol2scm ("volta-numbers");
-          SCM start_nums = get_property (layer.start_ev_, volta_numbers_sym);
-          SCM these_nums = get_property (ev, volta_numbers_sym);
-          if (!ly_is_equal (these_nums, start_nums))
+          // If there is a current bracket which was created by an event, ignore
+          // unrelated stop events, which are recognized by a difference in
+          // their list of volta numbers.
+          //
+          // Unrelated stop events might arise from differences in grace notes
+          // among elements of simultaneous music (issue #34).  In this case, at
+          // the earliest grace time, we expect the current bracket to end.  Any
+          // events for that ended bracket which arrive at a later grace time
+          // are quietly ignored rather than allowed to end a different bracket.
+          //
+          // Unrelated stop events might arise from other incongruous repeat
+          // structure in simultaneous music.  Are there any cases where it
+          // would be helpful to warn here, or are existing warnings sufficient?
+          const bool accept_event = [&] {
+            if (!layer.bracket_) // lacking information required to filter
+              {
+                return true;
+              }
+
+            auto *const bracket_start_ev = layer.bracket_->event_cause ();
+            if (!bracket_start_ev) // lacking information required to filter
+              {
+                return true;
+              }
+
+            return are_volta_numbers_equal (bracket_start_ev, ev);
+          }();
+
+          if (accept_event)
             {
-              if (!layer.stop_prev_ev_)
-                layer.stop_prev_ev_ = ev;
-            }
-          else
-            {
-              if (!layer.stop_curr_ev_)
-                layer.stop_curr_ev_ = ev;
+              layer.stop_prev_ev_ = ev;
             }
         }
     }
@@ -246,14 +285,54 @@ Volta_engraver::process_music ()
             }
         }
 
-      layer.start_bracket_this_timestep_ = manual_start || layer.start_ev_;
+      layer.start_bracket_this_timestep_ = [&] {
+        if (!(manual_start || layer.start_ev_))
+          {
+            return false; // We have no reason to start a bracket.
+          }
+
+        // If there is no current bracket, or if the current bracket will stop
+        // here, we can start a new one without trouble.
+        if (!layer.bracket_ || end)
+          {
+            return true;
+          }
+
+        // We have reason to start a new bracket, but no clear reason to stop
+        // the current one.  Differences in grace notes among elements of
+        // simultaneous music cause volta events to be announced in more than
+        // one time step (issue #34).  Do not split the current bracket just for
+        // this; let it continue.
+        if (layer.start_mom_.main_part_ == now_mom ().main_part_)
+          {
+            // Compare volta specs to gain confidence that we are handling grace
+            // synchronization rather than incongruous repeat structure.
+            //
+            // Manually created (via repeatCommands) brackets do not have volta
+            // numbers: they have only markup.  We refrain from trying to fix
+            // them blindly.
+            if (layer.start_ev_)
+              {
+                if (auto *const prev_ev = layer.bracket_->event_cause ())
+                  {
+                    if (are_volta_numbers_equal (prev_ev, layer.start_ev_))
+                      {
+                        // The volta numbers are the same as for the current
+                        // bracket.  We're probably seeing issue #34: don't
+                        // start a new bracket.
+                        return false;
+                      }
+                  }
+              }
+          }
+
+        return true;
+      }();
+
       if (layer.start_bracket_this_timestep_ && layer.bracket_ && !end)
         {
-          if (manual_start)
-            {
-              layer.bracket_->warning (_ ("already have a VoltaBracket;"
-                                          "ending it prematurely"));
-            }
+          layer.bracket_->warning (
+            _ ("already have a VoltaBracket; ending it prematurely"));
           end = true;
         }
 
