@@ -22,6 +22,7 @@ import getopt
 import os
 import re
 import sys
+import zlib
 
 import fontforge
 import psMat
@@ -94,8 +95,9 @@ for glyph in font.glyphs():
 lisp = b""
 for sub in subfonts:
     lisp += open(os.path.join(indir, sub) + ".lisp", "rb").read()
+compressed_lisp = zlib.compress(lisp, 9)
 
-font.setTableData("LILC", lisp)
+font.setTableData("LILC", compressed_lisp)
 font.setTableData("LILY", b'(design_size . 20)')
 
 font.generate(output)
