@@ -18,38 +18,12 @@
 # along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 
 
-from fractions import Fraction
+import re
 
 import lilylib as ly
 import musicexp
 
 
-def rational_to_lily_duration(rational_len):
-    d = musicexp.Duration()
-
-    d_log = {1: 0, 2: 1, 4: 2, 8: 3, 16: 4, 32: 5, 64: 6,
-             128: 7, 256: 8, 512: 9}.get(rational_len.denominator, -1)
-
-    # Duration of the form 1/2^n or 3/2^n can be converted to a simple lilypond duration
-    dots = {1: 0, 3: 1, 7: 2, 15: 3, 31: 4, 63: 5,
-            127: 6}.get(rational_len.numerator, -1)
-    if d_log >= dots >= 0:
-        # account for the dots!
-        d.duration_log = d_log - dots
-        d.dots = dots
-    elif d_log >= 0:
-        d.duration_log = d_log
-        d.factor = Fraction(rational_len.numerator)
-    else:
-        ly.warning(_("Encountered rational duration with denominator %s, "
-                     "unable to convert to lilypond duration") %
-                   rational_len.denominator)
-        # TODO: Test the above error message
-        return None
-
-    return d
-
-
 def musicxml_step_to_lily(step):
     if step:
         return (ord(step) - ord('A') + 7 - 2) % 7
@@ -57,10 +31,36 @@ def musicxml_step_to_lily(step):
         return None
 
 
+def musicxml_numbers_to_volte(number_string):
+    res = []
+
+    # Volta numbers are separated by commas, optionally followed by a space
+    # (XML extraction already removed leading and trailing whitespace, also
+    # squeezing sequences of whitespace characters inbetween into single
+    # spaces).
+    #
+    # An empty string is also valid input, but the return value is still an
+    # empty list.
+    numbers = re.split(r', ?', number_string)
+    for number in numbers:
+        # According to the standard, no leading zeroes are allowed.  We
+        # ignore this restriction, simply using `int` for the conversion to
+        # integers.
+        try:
+            n = int(number)
+        except ValueError:
+            return []
+
+        if n > 0:
+            res.append(n)
+        else:
+            return []
+    return res
+
+
 class Marker(musicexp.Music):
     def __init__(self):
         self.direction = 0
-        self.event = None
 
     def print_ly(self, printer):
         ly.warning(_("Encountered unprocessed marker %s\n") % self)
@@ -73,8 +73,23 @@ class Marker(musicexp.Music):
 class RepeatMarker(Marker):
     def __init__(self):
         Marker.__init__(self)
-        self.times = 0
+        self.times = 2  # A simple repeat played twice as the default.
+        self.at_start = False
 
 
 class EndingMarker(Marker):
-    pass
+    def __init__(self):
+        Marker.__init__(self)
+        self.mxl_event = None
+        self.volte = []
+
+
+class RepeatEndingMarker(RepeatMarker, EndingMarker):
+    def __init__(self, repeat, ending):
+        self.direction = repeat.direction
+        # According to the standard, `times` is not used if there is an
+        # `<ending>` element at the same time.
+        self.times = None
+        self.at_start = repeat.at_start
+        self.mxl_event = ending.mxl_event
+        self.volte = ending.volte
