@@ -3,7 +3,7 @@
 #
 # This file is part of LilyPond, the GNU music typesetter.
 #
-# Copyright (C) 2016--2022 John Gourlay <john@weathervanefarm.net>
+# Copyright (C) 2016--2023 John Gourlay <john@weathervanefarm.net>
 #
 # LilyPond is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,26 +22,14 @@
 import re
 
 
-def string_to_number(s):
-    try:
-        return int(s)
-    except ValueError:
-        return float(s)
-
-
-def string_to_integer(s):
-    num = string_to_number(s)
-    if isinstance(num, int):
-        return num
-    else:
-        return int(num)
-
-
 def escape_ly_output_string(input_string):
     return_string = input_string
-    needs_quotes = not re.match("^[a-zA-ZäöüÜÄÖßñ]*$", return_string)
+    needs_quotes = not re.match("^[a-zA-ZäöüÜÄÖßñ]+$", return_string)
     if needs_quotes:
-        return_string = "\"" + return_string.replace("\"", "\\\"") + "\""
+        return_string = ('"'
+                         + return_string.replace('\\', '\\\\')
+                                        .replace('"', r'\"')
+                         + '"')
     return return_string
 
 
@@ -55,7 +43,9 @@ def interpret_alter_element(alter_elm):
 
 
 def musicxml_duration_to_log(dur):
-    return {'256th': 8,
+    return {'1024th': 10,
+            '512th': 9,
+            '256th': 8,
             '128th': 7,
             '64th': 6,
             '32nd': 5,
@@ -69,34 +59,19 @@ def musicxml_duration_to_log(dur):
             'long': -2}.get(dur, 0)
 
 
-def hexcolorval_to_nr(hex_val):
-    try:
-        v = int(hex_val, 16)
-        if v == 255:
-            v = 256
-        return v / 256.
-    except ValueError:
-        return 0.
-
-
-def hex_to_color(hex_val):
-    res = re.match(
-        r'#([0-9a-f][0-9a-f]|)([0-9a-f][0-9a-f])([0-9a-f][0-9a-f])([0-9a-f][0-9a-f])$',
-        hex_val,
-        re.IGNORECASE)
-    if res:
-        return [hexcolorval_to_nr(x) for x in res.group(2, 3, 4)]
-    else:
-        return None
+def round_to_two_digits(val):
+    return round(val * 100) / 100
 
 
+# Examples:
+#
+#   r'"foo  \"bar  baz\"  urgh"'  ->  [r'"foo  \"bar  baz\"  urgh"']
+#   r'foo  "bar  baz"  urgh'      ->  ['foo', '"bar  baz"', 'urgh']
+#
+# We only split at ASCII whitespace characters, mainly to preserve the
+# non-breakable space character (U+0080).
 def split_string_and_preserve_doublequoted_substrings(value):
-    import shlex
-    lex = shlex.shlex(value)
-    lex.quotes = '"'
-    lex.whitespace_split = True
-    lex.commenters = ''
-    return list(lex)
+    return re.findall(r'(?asx) (?: " .*? [^\\] " | \S )+', value)
 
 
 def musicxml_sound_to_lilypond_midi_instrument(sound):
