@@ -245,15 +245,7 @@ class Ghostscript(ConfigurePackage):
         return []
 
     def configure_args(self, c: Config) -> List[str]:
-        mingw_args = []
-        if c.is_mingw():
-            mingw_args = [
-                # Some platforms have sys/times.h for native compilation;
-                # however, mingw doesn't have it. Ghostscript's doesn't
-                # handle this situation correctly.
-                "GCFLAGS=-DHAVE_SYS_TIMES_H=0",
-            ]
-        return mingw_args + [
+        args = [
             # Only enable drivers needed for LilyPond.
             "--disable-contrib",
             "--disable-dynamic",
@@ -273,6 +265,16 @@ class Ghostscript(ConfigurePackage):
             "--without-x",
         ]
 
+        if c.is_mingw():
+            args += [
+                # Some platforms have sys/times.h for native compilation;
+                # however, mingw doesn't have it. Ghostscript's doesn't
+                # handle this situation correctly.
+                "GCFLAGS=-DHAVE_SYS_TIMES_H=0",
+            ]
+
+        return args
+
     def exe_path(self, c: Config) -> str:
         """Return path to gs executable."""
         gs_exe = f"gs{c.program_suffix}"
@@ -289,6 +291,47 @@ class Ghostscript(ConfigurePackage):
 ghostscript = Ghostscript()
 
 
+class Libiconv(ConfigurePackage):
+    def enabled(self, c: Config) -> bool:
+        return c.is_macos() or c.is_mingw()
+
+    @property
+    def version(self) -> str:
+        return "1.18"
+
+    @property
+    def directory(self) -> str:
+        return f"libiconv-{self.version}"
+
+    @property
+    def archive(self) -> str:
+        return f"{self.directory}.tar.gz"
+
+    @property
+    def download_url(self) -> str:
+        return f"https://ftpmirror.gnu.org/gnu/libiconv/{self.archive}"
+
+    def get_env_variables(self, c: Config) -> Dict[str, str]:
+        """Return environment variables to make libiconv available."""
+        libiconv_install = self.install_directory(c)
+        return {
+            "CPATH": os.path.join(libiconv_install, "include"),
+            # Cannot use LIBRARY_PATH because it is only used if GCC is built
+            # as a native compiler, so it doesn't work for mingw.
+            "LDFLAGS": "-L" + os.path.join(libiconv_install, "lib"),
+        }
+
+    @property
+    def license_files(self) -> List[str]:
+        return ["COPYING"]
+
+    def __str__(self) -> str:
+        return f"libiconv {self.version}"
+
+
+libiconv = Libiconv()
+
+
 class Gettext(ConfigurePackage):
     def enabled(self, c: Config) -> bool:
         return c.is_freebsd() or c.is_macos() or c.is_mingw()
@@ -309,28 +352,6 @@ class Gettext(ConfigurePackage):
     def download_url(self) -> str:
         return f"https://ftpmirror.gnu.org/gnu/gettext/{self.archive}"
 
-    def _apply_patches_locale_charset(self, c: Config):
-        # localcharset.c defines locale_charset, which is also provided by
-        # Guile. However, Guile has a modification to this file so we really
-        # need to build that version.
-        def patch_makefile(content: str) -> str:
-            return content.replace("libgnu_la-localcharset.lo", "")
-
-        makefile = os.path.join("gettext-runtime", "intl", "gnulib-lib", "Makefile.in")
-        self.patch_file(c, makefile, patch_makefile)
-
-        def patch_dcigettext(content: str) -> str:
-            return content.replace("locale_charset ()", "NULL")
-
-        dcigettext = os.path.join("gettext-runtime", "intl", "dcigettext.c")
-        self.patch_file(c, dcigettext, patch_dcigettext)
-
-    def apply_patches(self, c: Config):
-        # On mingw, we build a shared libintl.dll (see below) so there is no
-        # problem with duplicate locale_charset (see above).
-        if not c.is_mingw():
-            self._apply_patches_locale_charset(c)
-
     @property
     def configure_script(self) -> str:
         return os.path.join("gettext-runtime", "configure")
@@ -480,16 +501,24 @@ class GLib(MesonPackage):
         return f"https://download.gnome.org/sources/glib/{major_version}/{self.archive}"
 
     def dependencies(self, c: Config) -> List[Package]:
-        gettext_dep: List[Package] = []
-        if c.is_freebsd() or c.is_macos() or c.is_mingw():
-            gettext_dep = [gettext]
-        return gettext_dep + [libffi, pcre2, zlib]
+        deps = [libffi, pcre2, zlib]
+        if gettext.enabled(c):
+            deps += [gettext]
+        if libiconv.enabled(c):
+            deps += [libiconv]
+        return deps
 
     def build_env_extra(self, c: Config) -> Dict[str, str]:
         env = super().build_env_extra(c)
-        if c.is_freebsd() or c.is_macos() or c.is_mingw():
+        if gettext.enabled(c):
             # Make meson find libintl.
             env.update(gettext.get_env_variables(c))
+        if libiconv.enabled(c):
+            # Make meson also find libiconv, prepending to the variables.
+            assert gettext.enabled(c)
+            libiconv_env_variables = libiconv.get_env_variables(c)
+            env["CPATH"] = f"{libiconv_env_variables['CPATH']}{os.pathsep}{env['CPATH']}"
+            env["LDFLAGS"] = f"{libiconv_env_variables['LDFLAGS']} {env['LDFLAGS']}"
         return env
 
     def meson_args_static(self, c: Config) -> List[str]:
@@ -499,13 +528,7 @@ class GLib(MesonPackage):
         return super().meson_args_static(c)
 
     def meson_args(self, c: Config) -> List[str]:
-        mingw_args = []
-        if c.is_mingw():
-            mingw_args = [
-                # Prevent using format specifiers that trigger GCC warnings.
-                "-Dc_args=-D__USE_MINGW_ANSI_STDIO",
-            ]
-        return mingw_args + [
+        args = [
             # Disable G_ENABLE_DEBUG as recommended by upstream.
             "-Dglib_debug=disabled",
             "-Dtests=false",
@@ -513,6 +536,14 @@ class GLib(MesonPackage):
             "-Dxattr=false",
         ]
 
+        if c.is_mingw():
+            args += [
+                # Prevent using format specifiers that trigger GCC warnings.
+                "-Dc_args=-D__USE_MINGW_ANSI_STDIO",
+            ]
+
+        return args
+
     @property
     def license_files(self) -> List[str]:
         return ["COPYING"]
@@ -564,37 +595,6 @@ class Bdwgc(ConfigurePackage):
 bdwgc = Bdwgc()
 
 
-class Libiconv(ConfigurePackage):
-    def enabled(self, c: Config) -> bool:
-        return c.is_mingw()
-
-    @property
-    def version(self) -> str:
-        return "1.18"
-
-    @property
-    def directory(self) -> str:
-        return f"libiconv-{self.version}"
-
-    @property
-    def archive(self) -> str:
-        return f"{self.directory}.tar.gz"
-
-    @property
-    def download_url(self) -> str:
-        return f"https://ftpmirror.gnu.org/gnu/libiconv/{self.archive}"
-
-    @property
-    def license_files(self) -> List[str]:
-        return ["COPYING"]
-
-    def __str__(self) -> str:
-        return f"libiconv {self.version}"
-
-
-libiconv = Libiconv()
-
-
 class Libunistring(ConfigurePackage):
     @property
     def version(self) -> str:
@@ -613,20 +613,21 @@ class Libunistring(ConfigurePackage):
         return f"https://ftpmirror.gnu.org/gnu/libunistring/{self.archive}"
 
     def dependencies(self, c: Config) -> List[Package]:
-        libiconv_dep: List[Package] = []
-        if c.is_mingw():
-            libiconv_dep = [libiconv]
-        return libiconv_dep
+        deps: List[Package] = []
+        if libiconv.enabled(c):
+            deps += [libiconv]
+        return deps
 
     def configure_args(self, c: Config) -> List[str]:
-        mingw_args = []
-        if c.is_mingw():
+        args = ["--disable-threads"]
+
+        if libiconv.enabled(c):
             libiconv_install_dir = libiconv.install_directory(c)
-            mingw_args = [
+            args += [
                 f"--with-libiconv-prefix={libiconv_install_dir}",
             ]
 
-        return ["--disable-threads"] + mingw_args
+        return args
 
     @property
     def license_files(self) -> List[str]:
@@ -744,19 +745,36 @@ class Guile(ConfigurePackage):
         makefile_in = os.path.join("libguile", "Makefile.in")
         self.patch_file(c, makefile_in, patch_makefile_in)
 
-
     def apply_patches(self, c: Config):
+        # Gnulib provides the file localcharset.c that defines locale_charset.
+        # It is compiled into multiple library archives, including libiconv.a,
+        # libintl.a, and libunistring.a. That works fine because the linker only
+        # pulls in object files that are needed to satisfy an unresolved symbol.
+        # Once provided, all future files and definitions will be ignored.
+        # Guile however modifies its localcharset.c to also provide the related
+        # function environ_locale_charset. Because that function is referenced
+        # and not provided by any other archive, the linker is forced to include
+        # Guile's copy of localcharset.c. This can lead to duplicate symbols for
+        # locale_charset if another archive already provided it.
+        # To avoid problems, rename the function definition in localcharset.c
+        # to guile_locale_charset, which is not referenced anywhere. The real
+        # locale_charset function is then provided by any of the other archives.
+        def patch_localcharset(content: str) -> str:
+            return content.replace("\nlocale_charset", "\nguile_locale_charset")
+
+        localcharset = os.path.join("lib", "localcharset.c")
+        self.patch_file(c, localcharset, patch_localcharset)
+
         if c.is_mingw():
             self._apply_patches_mingw(c)
 
     def dependencies(self, c: Config) -> List[Package]:
-        gettext_dep: List[Package] = []
-        if c.is_freebsd() or c.is_macos() or c.is_mingw():
-            gettext_dep = [gettext]
-        libiconv_dep: List[Package] = []
-        if c.is_mingw():
-            libiconv_dep = [libiconv]
-        return gettext_dep + libiconv_dep + [bdwgc, libffi, libunistring]
+        deps = [bdwgc, libffi, libunistring]
+        if gettext.enabled(c):
+            deps += [gettext]
+        if libiconv.enabled(c):
+            deps += [libiconv]
+        return deps
 
     def build_env_extra(self, c: Config) -> Dict[str, str]:
         env = super().build_env_extra(c)
@@ -769,44 +787,44 @@ class Guile(ConfigurePackage):
     def configure_args(self, c: Config) -> List[str]:
         libunistring_install_dir = libunistring.install_directory(c)
 
-        libintl_args = []
-        if c.is_freebsd() or c.is_macos() or c.is_mingw():
+        args = [
+            # Disable unused parts of Guile.
+            "--disable-networking",
+            # Disable -Werror to enable builds with newer compilers.
+            "--disable-error-on-warning",
+            # Disable LTO.
+            "--disable-lto",
+            # Enable builtin mini-gmp to avoid building GMP ourselves.
+            "--enable-mini-gmp",
+            # Make configure find the statically built dependencies.
+            f"--with-libunistring-prefix={libunistring_install_dir}",
+            # Prevent that configure searches for libcrypt.
+            "ac_cv_search_crypt=no",
+        ]
+
+        if gettext.enabled(c):
             gettext_install_dir = gettext.install_directory(c)
-            libintl_args = [
+            args += [
                 f"--with-libintl-prefix={gettext_install_dir}",
             ]
 
-        mingw_args = []
+        if libiconv.enabled(c):
+            libiconv_install_dir = libiconv.install_directory(c)
+            args += [
+                f"--with-libiconv-prefix={libiconv_install_dir}",
+            ]
+
         if c.is_mingw():
             guile_for_build = self.exe_path(c.native_config)
-            libiconv_install_dir = libiconv.install_directory(c)
-            mingw_args = [
+            args += [
                 f"GUILE_FOR_BUILD={guile_for_build}",
-                f"--with-libiconv-prefix={libiconv_install_dir}",
                 # Disable threads, not needed on Windows.
                 "--without-threads",
                 # Do not link against 'libbcrypt'.
                 "gl_cv_lib_assume_bcrypt=no",
             ]
 
-        return (
-            [
-                # Disable unused parts of Guile.
-                "--disable-networking",
-                # Disable -Werror to enable builds with newer compilers.
-                "--disable-error-on-warning",
-                # Disable LTO.
-                "--disable-lto",
-                # Enable builtin mini-gmp to avoid building GMP ourselves.
-                "--enable-mini-gmp",
-                # Make configure find the statically built dependencies.
-                f"--with-libunistring-prefix={libunistring_install_dir}",
-                # Prevent that configure searches for libcrypt.
-                "ac_cv_search_crypt=no",
-            ]
-            + libintl_args
-            + mingw_args
-        )
+        return args
 
     def exe_path(self, c: Config) -> str:
         """Return path to the guile interpreter."""
@@ -1251,12 +1269,12 @@ all_dependencies: List[Package] = [
     freetype,
     fontconfig,
     ghostscript,
+    libiconv,
     gettext,
     libffi,
     pcre2,
     glib,
     bdwgc,
-    libiconv,
     libunistring,
     guile,
     harfbuzz,
