@@ -191,8 +191,8 @@ shallow. Ranges from@tie{}@w{0} to infinity (@tie{}@code{0}=no limit,
 corresponding to one unit of @code{beatStructure}.")
      (beatExtraVelocity ,integer? "Extra MIDI velocity added by the
 @samp{Beat_performer} at the start of each beat.")
-     (beatStructure ,list? "A sequence describing the length of each beat in the
-measure in units of @code{beatBase}.")
+     (beatStructure ,number-list? "A sequence describing the length of each beat
+in the measure in units of @code{beatBase}.")
      (breathMarkType ,symbol? "The type of @code{BreathingSign} to create at
 @code{\\breathe}.")
 
@@ -756,6 +756,12 @@ one).")
 subdivided by omitting a number of beamlets, dependent on
 @code{beamMaximumSubdivision}, between beats at multiples of
 @code{beamMinimumSubdivision}.")
+     (submeasureBarType ,string? "Bar line to insert at submeasure boundaries
+specified by @code{submeasureStructure}, when @code{submeasureBarsEnabled}
+allows.")
+     (submeasureStructure ,number-list? "A sequence describing subdivisions of a
+measure.  Each element tells the distance from the previous division in units of
+@code{beatBase}.")
      (suggestAccidentals ,boolean-or-symbol? "If set to @code{#t},
 accidentals are typeset as suggestions above the note.  Setting it to
 @code{'cautionary} only applies that to cautionary accidentals.")
@@ -920,6 +926,10 @@ also contain @code{((@var{octave} . @var{name}) . (@var{alter}
      (melismaBusy ,boolean? "Signifies whether a melisma is active.
 This can be used to signal melismas on top of those automatically
 detected.")
+     (meterScalingFactor ,number? "The factor by which local nominal time
+signature settings must be scaled to fit the measure defined in the
+@code{Timing} context.  This must not be set in the @code{Timing} context.
+Readers should use@tie{}1 as the default when this property is not set.")
      (midiSkipOffset ,ly:moment? "This is the accrued MIDI offset to
 account for time skipped via @code{skipTypesetting}.")
 
@@ -954,6 +964,9 @@ the first segno, 1@tie{}from the first to the second segno,
      (stringFretFingerList ,list? "A list containing three entries.
 In @code{TabVoice} and @code{FretBoards} they determine the string, fret and
 finger to use")
+     (submeasureBarsEnabled ,boolean? "Whether to insert submeasure bar lines at
+boundaries specified by @code{submeasureStructure}.  They are typically enabled
+selectively to clarify complex rhythms.")
 
 
      (tieMelismaBusy ,boolean? "Signal whether a tie is present.")
