@@ -1090,10 +1090,6 @@ it.")
      (shortest-duration-space ,number? "Start with this multiple of
 @code{spacing-increment} space for the shortest duration.  See also
 @rinternals{spacing-spanner-interface}.")
-     (shortest-playing-duration ,ly:moment? "The duration of the
-shortest note playing here.")
-     (shortest-starter-duration ,ly:moment? "The duration of the
-shortest note that starts here.")
      (show-control-points ,boolean? "For grobs printing Bézier
 curves, setting this property to @code{#t} causes the control points
 and control polygon to be drawn on the page for ease of tweaking.")
@@ -1297,8 +1293,12 @@ the @code{staff-staff-spacing} property of the staff's
 @code{VerticalAxisGroup} grob is set, that is used instead.  See
 @code{staff-staff-spacing} for a description of the alist
 structure.")
-     (stem-attachment ,number-pair? "An @code{(@var{x} . @var{y})}
-pair where the stem attaches to the notehead.")
+
+     (stem-attachment ,number-pair? "An @code{(@var{x} . @var{y})} pair
+where the stem attaches to the note head.  Each component is measured in
+a -1 to@tie{}1 scale so that -1 is the left/bottom edge of the note's
+bounding box and 1@tie{}is the right/top edge.")
+
      (stem-begin-position ,number? "User override for the
 begin position of a stem.")
      ;;[TODO: doco]
@@ -1828,6 +1828,10 @@ maxima in a ligature.")
      (right-up-stem ,boolean? "request an upward right stem for a final
 longa or maxima in a ligature.")
 
+     (shortest-playing-duration ,positive-musical-length-as-number? "The
+duration of the shortest note playing here.")
+     (shortest-starter-duration ,positive-musical-length-as-number? "The
+duration of the shortest note that starts here.")
      (stropha ,boolean? "Is this neume a stropha?")
 
      (virga ,boolean? "Is this neume a virga?")
