@@ -1104,12 +1104,14 @@ Place a capo indicator (a large solid bar) across the entire fretboard
 at fret location @var{fret-number}.  Also, set fret @var{fret-number}
 to be the lowest fret on the fret diagram.
 
+@c Not really a function, but...
+@funindex place-fret
 @item (place-fret @var{string-number} @var{fret-number} [@var{finger-value}] [@var{color-modifier}] [@var{color}] ['parenthesized ['default-paren-color]])
 Place a fret playing indication on string @var{string-number} at fret
 @var{fret-number} with an optional fingering label @var{finger-value},
 an optional color modifier @var{color-modifier}, an optional color
 @var{color}, an optional parenthesis @code{'parenthesized} and an
-optional paranthesis color @code{'default-paren-color}.
+optional parenthesis color @code{'default-paren-color}.
 
 By default, the fret playing indicator is a solid dot.  This can be
 globally changed by setting the value of the property @code{dot-color}
