@@ -1,6 +1,6 @@
 ;;;; This file is part of LilyPond, the GNU music typesetter.
 ;;;;
-;;;; Copyright (C) 2007--2022 Joe Neeman <joeneeman@gmail.com>
+;;;; Copyright (C) 2007--2023 Joe Neeman <joeneeman@gmail.com>
 ;;;;
 ;;;; LilyPond is free software: you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -18,23 +18,23 @@
 
 (define-module (lily graphviz)
   #:use-module (lily)
+  #:use-module (srfi srfi-9)
   #:export
   (make-empty-graph add-node add-edge add-cluster
                     graph-write
                     ))
 
-(define graph-type (make-record-type "graph" '(nodes edges clusters name)))
+(define-record-type <graph>
+  (make-graph nodes edges clusters name)
+  graph?
+  (nodes nodes set-nodes!)
+  (edges edges set-edges!)
+  (clusters clusters set-clusters!)
+  ;; Unused field?
+  (name name))
 
-(define make-graph (record-constructor graph-type))
 (define (make-empty-graph name) (make-graph '() '() '() name))
 
-(define nodes (record-accessor graph-type 'nodes))
-(define edges (record-accessor graph-type 'edges))
-(define clusters (record-accessor graph-type 'clusters))
-(define set-nodes! (record-modifier graph-type 'nodes))
-(define set-edges! (record-modifier graph-type 'edges))
-(define set-clusters! (record-modifier graph-type 'clusters))
-
 (define (add-cluster graph node-id cluster-name)
   (let* ((cs (clusters graph))
          (cluster (assoc cluster-name cs))
@@ -62,7 +62,7 @@
         (es (edges graph))
         (cs (clusters graph)))
     (if (file-port? out)
-      (ly:message (G_ "Writing graph to `~a'...\n") (port-filename out)))
+        (ly:message (G_ "Writing graph to `~a'...\n") (port-filename out)))
     (display "digraph G {\nrankdir=\"LR\"\nnode [shape=rectangle]\n" out)
     (for-each (lambda (n) (format out "~a [label=\"~a\"]\n" (car n) (cdr n)))
               ns)
@@ -70,9 +70,7 @@
               es)
     (for-each (lambda (c)
                 (format out "subgraph cluster_~a {\nlabel= \"~a\"\ncolor=blue\n"
-                        (cond-expand
-                         (guile-2 (string-filter char-alphabetic? (car c)))
-                         (else (string-filter (car c) char-alphabetic?)))
+                        (string-filter char-alphabetic? (car c))
                         (car c))
                 (for-each (lambda (n) (format out "~a\n" n)) (cdr c))
                 (display "}\n" out))
