@@ -239,10 +239,12 @@ output glyphs as described by the Cairo structure `cairo_text_cluster_t`."
                              (+ (car offset) (cdr x-ext))
                              (+ (cdr offset) (cdr y-ext))
 
-                             ;; Backslashes are not valid
-                             ;; file URI path separators.
                              (ly:string-percent-encode
-                              (ly:string-substitute "\\" "/" file))
+                              (if (eq? PLATFORM 'windows)
+                                  ;; Backslashes are not valid
+                                  ;; file URI path separators.
+                                  (ly:string-substitute "\\" "/" file)
+                                  file))
 
                              (cadr location)
                              (caddr location)
