@@ -587,29 +587,85 @@ encloses the contents."
      (make-filled-box-stencil (cons (cdr xext) (+ (cdr xext) thick)) yext)
      (make-filled-box-stencil (cons (- (car xext) thick) (car xext)) yext))))
 
-;; TODO merge this and prev function.
 (define-public (box-stencil stencil thickness padding)
-  "Add a box around @var{stencil}, producing a new stencil."
-  (let* ((x-ext (interval-widen (ly:stencil-extent stencil 0) padding))
-         (y-ext (interval-widen (ly:stencil-extent stencil 1) padding))
-         (y-rule (make-filled-box-stencil (cons 0 thickness) y-ext))
-         (x-rule (make-filled-box-stencil
-                  (interval-widen x-ext thickness) (cons 0 thickness))))
-    (set! stencil (ly:stencil-combine-at-edge stencil X 1 y-rule padding))
-    (set! stencil (ly:stencil-combine-at-edge stencil X -1 y-rule padding))
-    (set! stencil (ly:stencil-combine-at-edge stencil Y 1 x-rule 0.0))
-    (set! stencil (ly:stencil-combine-at-edge stencil Y -1 x-rule 0.0))
-    stencil))
+  "Add a box around @var{stencil}, producing a new stencil.
 
-(define-public (circle-stencil stencil thickness padding)
-  "Add a circle around @var{stencil}, producing a new stencil."
+The spacing characteristics are preserved if either a @code{\\hspace} or a
+@code{\\vspace} command (with either positive or negative values) gets boxed.
+This means that @var{padding} and @var{thickness} added to an empty extent will
+not participate in spacing and is not recognized by skylines."
+  (let* ((normalize-ext
+          (lambda (i)
+            ;; Replace +/-inf.0 by zero; do not reorder if car > cdr.
+            (cons (if (inf? (car i)) 0.0 (car i))
+                  (if (inf? (cdr i)) 0.0 (cdr i)))))
+         (ext-translate
+          (lambda (ext amount)
+            (cons (+ (car ext) amount) (+ (cdr ext) amount))))
+         (negative-ext?
+          (lambda (ext)
+            (> (car ext) (cdr ext))))
+
+         (raw-x-ext (ly:stencil-extent stencil X))
+         (raw-y-ext (ly:stencil-extent stencil Y))
+         (x-ext (normalize-ext raw-x-ext))
+         (y-ext (normalize-ext raw-y-ext))
+         (negative-x? (negative-ext? raw-x-ext))
+         (negative-y? (negative-ext? raw-y-ext))
+         (x-thick (if negative-x? (- thickness) thickness))
+         (y-thick (if negative-y? (- thickness) thickness))
+         (thick-x-ext (cons 0 x-thick))
+         (thick-y-ext (cons 0 y-thick))
+         (pad-x-ext
+          (interval-widen x-ext (if negative-x? (- padding) padding)))
+         (pad-y-ext
+          (interval-widen y-ext (if negative-y? (- padding) padding)))
+         (width-ext (interval-widen pad-x-ext x-thick))
+         (height-ext (interval-widen pad-y-ext y-thick))
+
+         (boxed-stencil
+          (ly:stencil-add
+           stencil
+           (make-filled-box-stencil     ; left/right
+            (ext-translate thick-x-ext (car width-ext))
+            height-ext)
+           (make-filled-box-stencil     ; right/left
+            (ext-translate thick-x-ext (cdr pad-x-ext))
+            height-ext)
+           (make-filled-box-stencil     ; top/bottom
+            width-ext
+            (ext-translate thick-y-ext (car height-ext)))
+           (make-filled-box-stencil     ; bottom/top
+            width-ext
+            (ext-translate thick-y-ext (cdr pad-y-ext)))))
+
+         (h-space? (ly:stencil-empty? stencil Y))
+         (v-space? (ly:stencil-empty? stencil X)))
+    (ly:make-stencil
+     (ly:stencil-expr boxed-stencil)
+     (if (or h-space? v-space? negative-x?)
+         raw-x-ext
+         (ly:stencil-extent boxed-stencil X))
+     (if (or h-space? v-space? negative-y?)
+         raw-y-ext
+         (ly:stencil-extent boxed-stencil Y)))))
+
+(define*-public (circle-stencil stencil thickness padding
+                                #:optional (bbox #f))
+  "Add a circle around @var{stencil}, producing a new stencil.
+
+If optional argument @var{bbox} is set to @code{#t}, use the bounding box of
+@var{stencil} as the circle's diameter.  Otherwise, use either the width or
+height of @var{stencil} (whatever is larger)."
   (let* ((x-ext (ly:stencil-extent stencil X))
          (y-ext (ly:stencil-extent stencil Y))
-         (diameter (max (interval-length x-ext)
-                        (interval-length y-ext)))
+         (x-length (interval-length x-ext))
+         (y-length (interval-length y-ext))
+         (diameter (if bbox
+                       (ly:length x-length y-length)
+                       (max x-length y-length)))
          (radius (+ (/ diameter 2) padding thickness))
          (circle (make-circle-stencil radius thickness #f)))
-
     (ly:stencil-add
      stencil
      (ly:stencil-translate circle
@@ -716,17 +772,24 @@ color formats."
 (define*-public (stencil-whiteout-outline
                  stil #:optional (thickness 0.3) (color white)
                  (angle-increments 16) (radial-increments 1))
-  "White-out a stencil by surrounding it with white (or @var{color}) around
-its outline.
+  "White-out stencil @var{stil} by surrounding its outline with white.
 
-This function works by creating a series of white or @var{color}
-stencils radially offset from the original stencil with angles from
-0 to 2*pi, at an increment of @code{angle-inc}, and with radii
-from @code{radial-inc} to @var{thickness}.  @var{thickness} is how big
-the white outline is, as a multiple of @code{line-thickness}.
-@var{radial-increments} is how many copies of the white stencil we make
-on our way out to thickness.  @var{angle-increments} is how many copies
-of the white stencil we make between 0 and 2*pi."
+This function works by creating a series of white stencils radially offset from
+the original stencil with angles from 0° to 360°.
+
+Optional argument @var{thickness} (default value 0.3) specifies how big the
+white outline is.
+
+The number of angle increments can be controlled with optional argument
+@var{angle-increments}, defaulting to value 16 (corresponding to 22.5°).  The
+number of radius increments (from zero to @var{thickness}) can be controlled
+with optional argument @var{radial-increments}, defaulting to value@tie{}1.
+Thus @var{radial-increments} specifies how many copies of the white stencil we
+make on our way out to @var{thickness}, and @var{angle-increments} how many
+copies of the white stencil we make between 0° and 360°.  In total,
+@var{radial-increments}*@var{angle-increments} copies are drawn.
+
+Optional argument @var{color} changes the white-out color (defaulting to white)."
   (if (or (not (positive? angle-increments))
           (not (positive? radial-increments)))
       (begin
@@ -768,11 +831,14 @@ of the white stencil we make between 0 and 2*pi."
 (define*-public (stencil-whiteout-box stil
                                       #:optional (thickness 0) (blot 0)
                                       (color white))
-  "White-out a stencil by printing it on top of a white (or @var{color})
-rectangle.
+  "White-out stencil @var{stil} by printing it on top of a white rectangle.
 
-@var{thickness} is how far, as a multiple of @code{line-thickness},
-the white outline extends past the extents of stencil @var{stil}."
+By default, the white background rectangle encloses @var{stil} without any
+borders; this can be changed by setting optional argument @var{thickness}
+(defaulting to value zero).  Optional argument @var{blot} gives the blot
+diameter for rounding the corners of the background rectangle (default value is
+zero, making sharp corners).  Optional argument @var{color} changes the
+background color (defaulting to white)."
   (let*
       ((x-ext (interval-widen (ly:stencil-extent stil X) thickness))
        (y-ext (interval-widen (ly:stencil-extent stil Y) thickness)))
@@ -783,20 +849,26 @@ the white outline extends past the extents of stencil @var{stil}."
 
 (define*-public (stencil-whiteout stil
                                   #:optional style thickness
-                                  (line-thickness 0.1))
-  "White-out a stencil (i.e., add a white background around it).
+                                  (line-thickness 0.1)
+                                  (color white))
+  "White-out stencil @var{stil} (i.e., add a white background around it).
 
-@var{style}, @var{thickness} and @var{line-thickness} are optional
-arguments.  If set, @var{style} determines the shape of the white
-background.  Given @code{'outline} the white background is produced
-by @code{stencil-whiteout-outline}, given @code{'rounded-box} it is
-produced by @code{stencil-whiteout-box} with rounded corners, given
-other arguments (e.g., @code{'box}) or when unspecified it defaults to
-@code{stencil-whiteout-box} with square corners.  If @var{thickness} is
-specified it determines how far, as a multiple of @var{line-thickness},
-the white background extends past the extents of stencil @var{stil}.  If
-@var{thickness} has not been specified, an appropriate default is chosen
-based on @var{style}."
+If set, optional argument @var{style} determines the shape of the white
+background: value @code{'outline} makes the function use
+@code{stencil-whiteout-outline} to produce the white background, value
+@code{'rounded-box} applies @code{stencil-whiteout-box} to produce a white
+background with rounded corners.  If other values are given (e.g., @code{'box})
+or when unspecified, @code{stencil-whiteout-box} is used to produce a white
+background with square corners.
+
+If optional argument @var{thickness} is specified it determines how far, as a
+multiple of @var{line-thickness} (which is an optional argument, too, defaulting
+to value 0.1), the white background extends past the extents of @var{stil}.  If
+@var{thickness} is not specified, an appropriate default is chosen based on
+@var{style}.
+
+Optional argument @var{color} sets the color of the white-out, defaulting to
+white."
   (let ((thick (* line-thickness
                   (if (number? thickness)
                       thickness
@@ -806,9 +878,10 @@ based on @var{style}."
                        (else 0))))))
     (cond
      ((eq? style 'special) stil)
-     ((eq? style 'outline) (stencil-whiteout-outline stil thick))
-     ((eq? style 'rounded-box) (stencil-whiteout-box stil thick (* 2 thick)))
-     (else (stencil-whiteout-box stil thick)))))
+     ((eq? style 'outline) (stencil-whiteout-outline stil thick color))
+     ((eq? style 'rounded-box) (stencil-whiteout-box
+                                stil thick (* 2 thick) color))
+     (else (stencil-whiteout-box stil thick 0 color)))))
 
 (define-public (arrow-stencil-maker start? end?)
   "Return a function drawing a line from current point to @code{destination},
