@@ -18,13 +18,13 @@
 # along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 
 
-#  Build html versions of sections of LilyPond Contributor's Guide
+#  Build HTML versions of sections of LilyPond Contributor's Guide
 #
 #  Usage:  ./cg-section.sh SECTION
 #
 #    where SECTION is the section to be built.
 #
-#  For example, CG 4 would be built by
+#  For example, CG 5 would be built by
 #       ./cg-section.sh doc-work
 #
 #  At the end of the run, the user is prompted whether or not to
@@ -42,9 +42,10 @@
 
 usage () {
     cat <<EOF >&2
-Usage: $0 SECTION
 
+Usage: $0 SECTION
 e.g. $0 doc-work
+
 EOF
     exit "$1"
 }
@@ -61,36 +62,68 @@ else
     cd "`dirname $0`"
     cd ../..
     LILYPOND_GIT="`pwd`"
-    echo "\$LILYPOND_GIT was not set; auto-detected source tree at $LILYPOND_GIT"
+    echo "\$LILYPOND_GIT is not set; auto-detected source tree at $LILYPOND_GIT"
+fi
+
+if [ -n "$BROWSER" ]; then
+    echo "Using browser from \$BROWSER: $BROWSER"
+else
+    echo "\$BROWSER not set; using firefox as default"
+    BROWSER="firefox"
 fi
 
 if test ! -e "$LILYPOND_GIT/DEDICATION"; then
-    echo "Error: $LILYPOND_GIT did not look like a LilyPond source tree; aborting." >&2
+    echo "Error: $LILYPOND_GIT does not look like a LilyPond source tree; aborting." >&2
     exit 1
 fi
 
 : "${LILYPOND_BUILD_DIR:=$LILYPOND_GIT/build}"
+if test ! -d "$LILYPOND_BUILD_DIR"; then
+    echo "$LILYPOND_BUILD_DIR does not exist; check your setting of LILYPOND_BUILD_DIR. Aborting." >&2
+    exit 1
+fi
+# Make path absolute.
+LILYPOND_BUILD_DIR=`cd "$LILYPOND_BUILD_DIR"; pwd`
+
 DOC_DIR="${LILYPOND_TEMPDOCS:-$LILYPOND_BUILD_DIR/tempdocs}"
-LILYPOND_BOOK="$LILYPOND_BUILD_DIR/out/bin/lilypond-book"
-TEXI2HTML="texi2html"
+mkdir -p "$DOC_DIR"
+MKDIRRC=$?
+if [ $MKDIRRC != 0 ]; then
+    echo "Cannot create \$LILYPOND_BUILD_DIR: $LILYPOND_BUILD_DIR"
+    exit $MKDIRRC
+else
+    cp "$LILYPOND_BUILD_DIR/Documentation/out/version.itexi" "$DOC_DIR"
+fi
+# Make path absolute.
+DOC_DIR=`cd "$DOC_DIR"; pwd`
+
+TEXI2ANY="texi2any"
 REFCHECK="$LILYPOND_GIT/scripts/auxiliar/ref_check.py"
 
 SECTION="$1"
-OUTPUT_DIR="$DOC_DIR/contributor"
+OUTPUT_DIR="$DOC_DIR/$SECTION"
 SECTION_PATH="$LILYPOND_GIT/Documentation/en/contributor/$SECTION.itexi"
 
 if test ! -e "$SECTION_PATH"; then
-    echo "$SECTION_PATH did not exist; is $SECTION a valid section in the Contributor's Guide?" >&2
+    echo "$SECTION_PATH does not exist; is $SECTION a valid section in the Contributor's Guide?" >&2
     exit 1
 fi
 
-if test ! -d "$OUTPUT_DIR/out"; then
-    mkdir -p "$OUTPUT_DIR/out"
+mkdir -p "$OUTPUT_DIR/out"
+MKDIRRC=$?
+if [ $MKDIRRC != 0 ]; then
+    echo "Cannot create \$OUTPUT_DIR/out: $OUTPUT_DIR_OUT/out"
+    exit $MKDIRRC
+fi
+mkdir -p "$OUTPUT_DIR/en"
+MKDIRRC=$?
+if [ $MKDIRRC != 0 ]; then
+    echo "Cannot create \$OUTPUT_DIR/en: $OUTPUT_DIR_OUT/en"
+    exit $MKDIRRC
 fi
 
-cp "$LILYPOND_GIT/Documentation/en/common-macros.itexi" "$OUTPUT_DIR/common-macros.itexi"
-cp "$LILYPOND_GIT/Documentation/en/macros.itexi" "$DOC_DIR/macros.itexi"
-cp "$LILYPOND_BUILD_DIR/Documentation/out/version.itexi" "$OUTPUT_DIR"
+cp "$LILYPOND_GIT/Documentation/en/macros.itexi" "$OUTPUT_DIR/en/macros.itexi"
+cp "$DOC_DIR/version.itexi" "$OUTPUT_DIR/version.itexi"
 
 if test -e "$OUTPUT_DIR/$SECTION.html"; then
     rm "$OUTPUT_DIR/$SECTION.html"
@@ -100,33 +133,37 @@ if test -e "$OUTPUT_DIR/out/$SECTION.texi"; then
     rm "$OUTPUT_DIR/out/$SECTION.texi"
 fi
 
+cp "$SECTION_PATH" "$OUTPUT_DIR/out/$SECTION.itexi"
+
 echo "Running RefCheck"
 python3 "$REFCHECK"
 
 cd "$DOC_DIR"
-echo "Running $TEXI2HTML"
-cat "$DOC_DIR/macros.itexi" "$SECTION_PATH" > "$OUTPUT_DIR/$SECTION.texi"
-
-"$TEXI2HTML" \
+echo "Running $TEXI2ANY --html"
+cat "$OUTPUT_DIR/en/macros.itexi" "$OUTPUT_DIR/out/$SECTION.itexi" > "$OUTPUT_DIR/$SECTION.texi"
+"$TEXI2ANY" \
+    --html \
     --no-validate \
+    --no-split \
     --output="$OUTPUT_DIR/out/$SECTION.html" \
-    --I="$LILYPOND_GIT/Documentation" \
-    --I="$OUTPUT_DIR/out" \
+    -I "$OUTPUT_DIR/out" \
+    -I "$LILYPOND_GIT/Documentation" \
     "$OUTPUT_DIR/$SECTION.texi"
 
+echo "Displaying output in $BROWSER; close browser window when done."
+
+$BROWSER $OUTPUT_DIR/out/$SECTION.html
+
 cat <<EOF
 
-The $SECTION section of the Contributor's Guide should now be viewable at
-
-  $OUTPUT_DIR/out/$SECTION.html
-
 If you want to keep the generated docs around for a while, answer
 'n' to the next question.  If you only needed them to quickly check
 something, view them now and then answer 'y' when you're done.
 
 EOF
 
-read -p "rm -rf $OUTPUT_DIR ? (y/n): "
+echo "Delete temp files? [y/n]"
+read REPLY;
 if [ "$REPLY" = "y" ]; then
     echo "deleting files"
     rm -rf "$OUTPUT_DIR"
